@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,8 +27,10 @@
 #include "baseform.h"
 #include "utilsns.h"
 #include "qtconnectmacros.h"
+#include <QActionGroup>
+#include <QTemporaryFile>
 
-const QString SchemaEditorForm::UntitledFile = QT_TR_NOOP("(untitled)");
+const QString SchemaEditorForm::UntitledFile { QT_TR_NOOP("(untitled)") };
 
 SchemaEditorForm::SchemaEditorForm(QWidget *parent) : QWidget(parent)
 {
@@ -177,11 +179,9 @@ void SchemaEditorForm::closeEvent(QCloseEvent *event)
 {
 	if(alert_frm->isVisible() || hasModifiedEditors())
 	{
-		Messagebox msgbox;
+		int res = Messagebox::confirm(tr("There are modified files! Do you want to exit without saving them?"));
 
-		msgbox.show(tr("There are modified files! Do you want to exit without saving them?"), Messagebox::ConfirmIcon, Messagebox::YesNoButtons);
-
-		if(msgbox.result() == QDialog::Rejected)
+		if(Messagebox::isRejected(res))
 			event->ignore();
 	}
 }
@@ -387,8 +387,6 @@ void SchemaEditorForm::saveAll()
 		}
 		catch(Exception &e)
 		{
-			//Messagebox msgbox;
-			//msgbox.show(e);
 			Messagebox::error(e, __PRETTY_FUNCTION__, __FILE__, __LINE__);
 			break;
 		}
@@ -399,13 +397,11 @@ void SchemaEditorForm::saveAll()
 
 void SchemaEditorForm::closeAll()
 {
-	Messagebox msgbox;
-
 	if(hasModifiedEditors())
 	{
-		msgbox.show(tr("There are modified files! Do you want to close them without save?"), Messagebox::ConfirmIcon, Messagebox::YesNoButtons);
+		int res = Messagebox::confirm(tr("There are modified files! Do you want to close them without save?"));
 
-		if(msgbox.result() == QDialog::Rejected)
+		if(Messagebox::isRejected(res))
 			return;
 	}
 
@@ -490,7 +486,7 @@ void SchemaEditorForm::loadFiles(const QStringList &filenames)
 	}
 	catch(Exception &e)
 	{
-		qApp->restoreOverrideCursor();
+		//qApp->restoreOverrideCursor();
 		throw Exception(e.getErrorMessage(), e.getErrorCode(), __PRETTY_FUNCTION__, __FILE__, __LINE__, &e);
 	}
 }
@@ -530,13 +526,12 @@ void SchemaEditorForm::addEditorTab(const QString &filename)
 void SchemaEditorForm::closeEditorTab(int idx, bool confirm_close)
 {
 	SourceEditorWidget *editor_wgt = dynamic_cast<SourceEditorWidget *>(editors_tbw->widget(idx));
-	Messagebox msgbox;
 
 	if(editor_wgt->isModified() && confirm_close)
 	{
-		msgbox.show(tr("The source code was modified! Do you really want to close it without save?"), Messagebox::ConfirmIcon, Messagebox::YesNoButtons);
+		int res = Messagebox::confirm(tr("The source code was modified! Do you really want to close it without save?"));
 
-		if(msgbox.result() == QDialog::Rejected)
+		if(Messagebox::isRejected(res))
 			return;
 	}
 
