@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,27 +19,26 @@
 #include "utilsns.h"
 #include "tableobject.h"
 
-const QString Catalog::QueryList("list");
-const QString Catalog::QueryAttribs("attribs");
-const QString Catalog::PgSqlTrue("t");
-const QString Catalog::PgSqlFalse("f");
-const QString Catalog::BoolField("_bool");
-const QString Catalog::ArrayPattern("((\\[)[0-9]+(\\:)[0-9]+(\\])=)?(\\{)((.)+(,)*)*(\\})$");
-const QString Catalog::PgModelerTempDbObj("__pgmodeler_tmp");
-const QString Catalog::InvFilterPattern("__invalid__pattern__");
-const QString Catalog::AliasPlaceholder("$alias$");
-const QString Catalog::EscapedNullChar("\\000");
+const QString Catalog::PgModelerTempDbObj {"__pgmodeler_tmp"};
+const QString Catalog::EscapedNullChar {"\\000"};
+const QString Catalog::QueryList {"list"};
+const QString Catalog::QueryAttribs {"attribs"};
+const QString Catalog::PgSqlTrue {"t"};
+const QString Catalog::PgSqlFalse {"f"};
+const QString Catalog::BoolField {"_bool"};
+const QString Catalog::ArrayPattern {"((\\[)[0-9]+(\\:)[0-9]+(\\])=)?(\\{)((.)+(,)*)*(\\})$"};
+const QString Catalog::InvFilterPattern {"__invalid__pattern__"};
+const QString Catalog::AliasPlaceholder{"$alias$"};
 
-/* This query retrieve all extension child object except for data types because
- * they are handled in extension catalog query */
-const QString Catalog::GetExtensionObjsSql("SELECT d.objid AS oid, e.extname AS name FROM pg_depend AS d \
-																					 LEFT JOIN pg_extension AS e ON e.oid = d.refobjid \
-																					 WHERE objid > 0 AND refobjid > 0 AND deptype='e' AND classid::regclass::text != 'pg_type'\
-																					 ORDER BY extname;");
-attribs_map Catalog::catalog_queries;
+const QString Catalog::GetExtensionObjsSql {
+	"SELECT d.objid AS oid, e.extname AS name FROM pg_depend AS d \
+		LEFT JOIN pg_extension AS e ON e.oid = d.refobjid \
+		WHERE objid > 0 AND refobjid > 0 AND deptype='e' AND classid::regclass::text != 'pg_type'\
+		ORDER BY extname;"
+};
 
-std::map<ObjectType, QString> Catalog::oid_fields=
-{ {ObjectType::Database, "oid"}, {ObjectType::Role, "oid"}, {ObjectType::Schema,"oid"},
+const std::map<ObjectType, QString> Catalog::oid_fields {
+	{ObjectType::Database, "oid"}, {ObjectType::Role, "oid"}, {ObjectType::Schema,"oid"},
 	{ObjectType::Language, "oid"}, {ObjectType::Tablespace, "oid"}, {ObjectType::Extension, "ex.oid"},
 	{ObjectType::Function, "pr.oid"}, {ObjectType::Aggregate, "pr.oid"}, {ObjectType::Operator, "op.oid"},
 	{ObjectType::OpClass, "op.oid"}, {ObjectType::OpFamily, "op.oid"}, {ObjectType::Collation, "cl.oid"},
@@ -52,22 +51,14 @@ std::map<ObjectType, QString> Catalog::oid_fields=
 	{ObjectType::Transform, "tr.oid"}, {ObjectType::Procedure, "pr.oid"}
 };
 
-std::map<ObjectType, QString> Catalog::ext_oid_fields={
-	{ObjectType::Constraint, "cs.conrelid"},
-	{ObjectType::Index, "id.indexrelid"},
-	{ObjectType::Trigger, "tg.tgrelid"},
-	{ObjectType::Rule, "rl.ev_class"},
-	{ObjectType::Policy, "pl.polrelid"}
-};
-
-std::map<ObjectType, QString> Catalog::obj_relnames={
+const std::map<ObjectType, QString> Catalog::obj_relnames {
 	{ObjectType::Aggregate, "pg_aggregate"},	{ObjectType::Cast, "pg_cast"},
 	{ObjectType::Collation, "pg_collation"},	{ObjectType::Column, "pg_attribute"},
 	{ObjectType::Constraint, "pg_constraint"},	{ObjectType::Conversion, "pg_conversion"},
 	{ObjectType::Database, "pg_database"},	{ObjectType::Domain, "pg_type"},
 	{ObjectType::Extension, "pg_extension"},	{ObjectType::EventTrigger, "pg_event_trigger"},
 	{ObjectType::ForeignDataWrapper, "pg_foreign_data_wrapper"},	{ObjectType::ForeignTable, "pg_foreign_table"},
-	{ObjectType::Function, "pg_proc"},	{ObjectType::Index, "pg_index"},
+	{ObjectType::Function, "pg_proc"},	{ObjectType::Index, "pg_class"},
 	{ObjectType::Operator, "pg_operator"},	{ObjectType::OpClass, "pg_opclass"},
 	{ObjectType::OpFamily, "pg_opfamily"},	{ObjectType::Policy, "pg_policy"},
 	{ObjectType::Language, "pg_language"},	{ObjectType::Procedure, "pg_proc"},
@@ -79,16 +70,8 @@ std::map<ObjectType, QString> Catalog::obj_relnames={
 	{ObjectType::View, "pg_class"}, {ObjectType::UserMapping, "pg_user_mapping"}
 };
 
-std::map<ObjectType, QString> Catalog::parent_aliases={
-	{ObjectType::Constraint, "tb"},
-	{ObjectType::Index, "tb"},
-	{ObjectType::Trigger, "tb"},
-	{ObjectType::Rule, "cl"},
-	{ObjectType::Policy, "tb"}
-};
-
-std::map<ObjectType, QString> Catalog::name_fields=
-{ {ObjectType::Database, "datname"}, {ObjectType::Role, "rolname"}, {ObjectType::Schema,"nspname"},
+const std::map<ObjectType, QString> Catalog::name_fields {
+	{ObjectType::Database, "datname"}, {ObjectType::Role, "rolname"}, {ObjectType::Schema,"nspname"},
 	{ObjectType::Language, "lanname"}, {ObjectType::Tablespace, "spcname"}, {ObjectType::Extension, "extname"},
 	{ObjectType::Function, "proname"}, {ObjectType::Aggregate, "proname"}, {ObjectType::Operator, "oprname"},
 	{ObjectType::OpClass, "opcname"}, {ObjectType::OpFamily, "opfname"}, {ObjectType::Collation, "collname"},
@@ -101,6 +84,24 @@ std::map<ObjectType, QString> Catalog::name_fields=
 	{ObjectType::Procedure, "proname"}
 };
 
+const std::map<ObjectType, QString> Catalog::ext_oid_fields {
+	{ObjectType::Constraint, "cs.conrelid"},
+	{ObjectType::Index, "id.indexrelid"},
+	{ObjectType::Trigger, "tg.tgrelid"},
+	{ObjectType::Rule, "rl.ev_class"},
+	{ObjectType::Policy, "pl.polrelid"}
+};
+
+const std::map<ObjectType, QString> Catalog::parent_aliases {
+	{ObjectType::Constraint, "tb"},
+	{ObjectType::Index, "tb"},
+	{ObjectType::Trigger, "tb"},
+	{ObjectType::Rule, "cl"},
+	{ObjectType::Policy, "tb"}
+};
+
+attribs_map Catalog::catalog_queries {};
+
 Catalog::Catalog()
 {
 	match_signature = true;
@@ -357,7 +358,7 @@ void Catalog::setObjectFilters(QStringList filters, bool only_matching, bool mat
 
 			if(!fmt_conds.isEmpty())
 			{
-				extra_filter_conds[obj_type] = fmt_conds.join(" OR ").replace(AliasPlaceholder, parent_aliases[obj_type]);
+				extra_filter_conds[obj_type] = fmt_conds.join(" OR ").replace(AliasPlaceholder, parent_aliases.at(obj_type));
 				fmt_conds.clear();
 			}
 		}
@@ -470,9 +471,9 @@ QString Catalog::getCatalogQuery(const QString &qry_type, ObjectType obj_type, b
 	if(exclude_ext_objs && obj_type!=ObjectType::Database &&	obj_type!=ObjectType::Role && obj_type!=ObjectType::Tablespace && obj_type!=ObjectType::Extension)
 	{
 		if(ext_oid_fields.count(obj_type)==0)
-			attribs[Attributes::NotExtObject]=getNotExtObjectQuery(oid_fields[obj_type]);
+			attribs[Attributes::NotExtObject]=getNotExtObjectQuery(oid_fields.at(obj_type));
 		else
-			attribs[Attributes::NotExtObject]=getNotExtObjectQuery(ext_oid_fields[obj_type]);
+			attribs[Attributes::NotExtObject]=getNotExtObjectQuery(ext_oid_fields.at(obj_type));
 	}
 
 	loadCatalogQuery(BaseObject::getSchemaName(obj_type));
@@ -545,25 +546,6 @@ void Catalog::executeCatalogQuery(const QString &qry_type, ObjectType obj_type,
 	}
 }
 
-/*unsigned Catalog::getObjectCount(ObjectType obj_type, const QString &sch_name, const QString &tab_name, attribs_map extra_attribs)
-{
-	try
-	{
-		ResultSet res;
-
-		extra_attribs[Attributes::Schema]=sch_name;
-		extra_attribs[Attributes::Table]=tab_name;
-
-		executeCatalogQuery(QueryList, obj_type, res, false, extra_attribs);
-		res.accessTuple(ResultSet::FirstTuple);
-		return res.getTupleCount();
-	}
-	catch(Exception &e)
-	{
-		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
-	}
-} */
-
 unsigned Catalog::getObjectsCount(std::vector<ObjectType> obj_types, bool incl_sys_objs, const QString &sch_name, const QString &tab_name, attribs_map extra_attribs)
 {
 	try
@@ -591,9 +573,8 @@ unsigned Catalog::getObjectsCount(std::vector<ObjectType> obj_types, bool incl_s
 
 			/* Removing the section of the query where columns are selected until the column extra_info,
 			 * and injecting a count(oid) instruction */
-			//sql.remove(sql.indexOf("SELECT"), sql.indexOf("FROM"));
 			sql.remove(sql.indexOf("SELECT"), sql.indexOf(extra_info_token) + extra_info_token.length());
-			sql.prepend(QString("SELECT count(%1) ").arg(oid_fields[obj_type]));
+			sql.prepend(QString("SELECT count(%1) ").arg(oid_fields.at(obj_type)));
 			queries.append(sql);
 		}
 
@@ -893,7 +874,7 @@ QString Catalog::getCommentQuery(const QString &oid_field, ObjectType obj_type,
 	{
 		attribs_map attribs={{ Attributes::Oid, oid_field },
 												 { Attributes::SharedObj, (is_shared_obj ? Attributes::True : "") },
-												 { Attributes::ObjRelationName, obj_relnames[obj_type] }};
+												 { Attributes::ObjRelationName, obj_relnames.at(obj_type) }};
 
 		loadCatalogQuery(query_id);
 		return schparser.getSourceCode(attribs).simplified();
@@ -980,7 +961,7 @@ std::vector<attribs_map> Catalog::getObjectsAttributes(ObjectType obj_type, cons
 
 		//Retrieve the comment catalog query. Only columns need to retreive comments in their own catalog query file
 		if(obj_type != ObjectType::Column)
-			extra_attribs[Attributes::Comment] = getCommentQuery(oid_fields[obj_type], obj_type, is_shared_obj);
+			extra_attribs[Attributes::Comment] = getCommentQuery(oid_fields.at(obj_type), obj_type, is_shared_obj);
 
 		return getMultipleAttributes(obj_type, extra_attribs);
 	}
@@ -1001,7 +982,7 @@ attribs_map Catalog::getObjectAttributes(ObjectType obj_type, unsigned oid, cons
 	catch(Exception &e)
 	{
 		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e,
-						QApplication::translate("Catalog","Object type: %1","", -1).arg(BaseObject::getSchemaName(obj_type)));
+										qApp->translate("Catalog","Object type: %1","", -1).arg(BaseObject::getSchemaName(obj_type)));
 	}
 }
 
@@ -1012,27 +993,25 @@ QString Catalog::getObjectOID(const QString &name, ObjectType obj_type, const QS
 		attribs_map attribs;
 		ResultSet res;
 
-		attribs[Attributes::CustomFilter] = QString("%1 = E'%2'").arg(name_fields[obj_type]).arg(name);
+		attribs[Attributes::CustomFilter] = QString("%1 = E'%2'").arg(name_fields.at(obj_type)).arg(name);
 		attribs[Attributes::Schema] = schema;
 		attribs[Attributes::Table] = table;
 		executeCatalogQuery(QueryList, obj_type, res, false, attribs);
 
 		if(res.getTupleCount() > 1)
-			throw Exception(QApplication::translate("Catalog","The catalog query returned more than one OID!","", -1),
+			throw Exception(qApp->translate("Catalog","The catalog query returned more than one OID!","", -1),
 											ErrorCode::Custom,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
-		else if(res.isEmpty())
+		if(res.getTupleCount() == 0)
 			return "0";
-		else
-		{
-			res.accessTuple(ResultSet::FirstTuple);
-			return res.getColumnValue(Attributes::Oid);
-		}
+
+		res.accessTuple(ResultSet::FirstTuple);
+		return res.getColumnValue(Attributes::Oid);
 	}
 	catch(Exception &e)
 	{
 		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e,
-						QApplication::translate("Catalog","Object type: %1","", -1).arg(BaseObject::getSchemaName(obj_type)));
+										qApp->translate("Catalog","Object type: %1","", -1).arg(BaseObject::getSchemaName(obj_type)));
 	}
 }
 
@@ -1071,7 +1050,7 @@ attribs_map Catalog::getServerAttributes()
 	catch(Exception &e)
 	{
 		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e,
-						QApplication::translate("Catalog","Object type: server","", -1));
+										qApp->translate("Catalog","Object type: server","", -1));
 	}
 
 	return attribs;
