@@ -18,49 +18,18 @@
 
 #include "resultset.h"
 #include "exception.h"
+#include <QDebug>
 
 ResultSet::ResultSet()
 {
 	sql_result = nullptr;
 	empty_result = false;
-	is_res_copied = false;
 	current_tuple = -1;
 }
 
-ResultSet::ResultSet(PGresult *sql_result)
+ResultSet::ResultSet(PGresult *sql_result) : ResultSet()
 {
-	QString str_aux;
-	int res_state;
-
-	if(!sql_result)
-		throw Exception(ErrorCode::AsgNotAllocatedSQLResult, __PRETTY_FUNCTION__, __FILE__, __LINE__);
-
-	this->sql_result=sql_result;
-	res_state=PQresultStatus(this->sql_result);
-
-	//Handling the status of the result
-	switch(res_state)
-	{
-		//Generating an error in case the server returns an incomprehensible response
-		case PGRES_BAD_RESPONSE:
-			throw Exception(ErrorCode::IncomprehensibleDBMSResponse, __PRETTY_FUNCTION__, __FILE__, __LINE__);
-
-		//Generating an error in case the server returns a fatal error
-		case PGRES_FATAL_ERROR:
-			str_aux=Exception::getErrorMessage(ErrorCode::DBMSFatalError)
-					.arg(PQresultErrorMessage(sql_result));
-			throw Exception(str_aux,ErrorCode::DBMSFatalError, __PRETTY_FUNCTION__, __FILE__, __LINE__);
-
-		//In case of sucess states the result will be created
-		default:
-			/* For any other result set status different from PGRES_TUPLES_OK
-			 * we flag the result set as empty since they either return no tuples
-			 * or aren't support at the moment by this class */
-			empty_result = res_state != PGRES_TUPLES_OK;
-			current_tuple = -1;
-			is_res_copied = false;
-		break;
-	}
+    initResultSet(sql_result);
 }
 
 ResultSet::~ResultSet()
@@ -68,18 +37,50 @@ ResultSet::~ResultSet()
 	clearResultSet();
 }
 
+void ResultSet::initResultSet(PGresult *sql_res)
+{
+    if(!sql_res)
+        throw Exception(ErrorCode::AsgNotAllocatedSQLResult, __PRETTY_FUNCTION__, __FILE__, __LINE__);
+
+    int res_state = -1;
+
+    clearResultSet();
+    this->sql_result = sql_res;
+    res_state = PQresultStatus(sql_res);
+
+    //Handling the status of the result
+    switch(res_state)
+    {
+        //Generating an error in case the server returns an incomprehensible response
+        case PGRES_BAD_RESPONSE:
+            throw Exception(ErrorCode::IncomprehensibleDBMSResponse, __PRETTY_FUNCTION__, __FILE__, __LINE__);
+
+        //Generating an error in case the server returns a fatal error
+        case PGRES_FATAL_ERROR:
+            throw Exception(Exception::getErrorMessage(ErrorCode::DBMSFatalError)
+                                .arg(PQresultErrorMessage(sql_res)),
+                            ErrorCode::DBMSFatalError, __PRETTY_FUNCTION__, __FILE__, __LINE__);
+
+        //In case of sucess states the result will be created
+        default:
+            /* For any other result set status different from PGRES_TUPLES_OK
+                 * we flag the result set as empty since they either return no tuples
+                 * or aren't support at the moment by this class */
+            empty_result = res_state != PGRES_TUPLES_OK;
+            current_tuple = -1;
+        break;
+    }
+}
+
 void ResultSet::clearResultSet()
 {
-	/* Destroy the resultset of the object if it was not copied
-		to another class instance (see 'operator =') */
-	if(sql_result && !is_res_copied)
-		PQclear(sql_result);
+   if(sql_result)
+      PQclear(sql_result);
 
 	//Reset the other attributes
-	sql_result=nullptr;
-	empty_result=false;
-	is_res_copied=false;
-	current_tuple=-1;
+    sql_result = nullptr;
+    empty_result = false;
+    current_tuple = -1;
 }
 
 QString ResultSet::getColumnName(int column_idx)
@@ -89,7 +90,10 @@ QString ResultSet::getColumnName(int column_idx)
 		throw Exception(ErrorCode::RefTupleColumnInvalidIndex, __PRETTY_FUNCTION__, __FILE__, __LINE__);
 
 	//Returns the column name on the specified index
-	return QString(PQfname(sql_result, column_idx));
+    //QString col_name { PQfname(sql_result, column_idx) };
+    //return col_name;
+
+    return { PQfname(sql_result, column_idx) };
 }
 
 QStringList ResultSet::getColumnNames()
@@ -332,20 +336,3 @@ bool ResultSet::isValid()
 	return (sql_result != nullptr);
 }
 
-void ResultSet::operator = (ResultSet &res)
-{
-	/* Mark the result parameter as copied, avoiding
-		the sql_result attribute to be deallocated */
-	res.is_res_copied=true;
-
-	/* If the resultset 'this' is allocated,
-		it will be deallocated to avoid memory leaks */
-	clearResultSet();
-
-	//Copy the parameter restulset attributes to 'this' resultset
-	this->current_tuple=res.current_tuple;
-	this->empty_result=res.empty_result;
-	this->sql_result=PQcopyResult(res.sql_result, PG_COPYRES_TUPLES | PG_COPYRES_ATTRS | PG_COPYRES_EVENTS);
-	this->is_res_copied=false;
-}
-
