@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,8 +20,10 @@
 #include "defaultlanguages.h"
 #include "utilsns.h"
 
-const QRegularExpression BaseFunction::ConfigParamPattern(QRegularExpression::anchoredPattern("([a-z]+)([a-z]|(_))*"),
-																													QRegularExpression::CaseInsensitiveOption);
+const QRegularExpression BaseFunction::ConfigParamPattern {
+	QRegularExpression::anchoredPattern("([a-z]+)([a-z]|(_))*"),
+	QRegularExpression::CaseInsensitiveOption
+};
 
 BaseFunction::BaseFunction()
 {
