@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -109,6 +109,16 @@ QString Language::getSourceCode(SchemaParser::CodeType def_type)
 	return this->getSourceCode(def_type, false);
 }
 
+void Language::updateDependencies()
+{
+	std::vector<BaseObject *> deps;
+
+	for(auto &func : functions)
+		deps.push_back(func);
+
+	BaseObject::updateDependencies(deps);
+}
+
 QString Language::getSourceCode(SchemaParser::CodeType def_type, bool reduced_form)
 {
 	QString code_def=getCachedCode(def_type, reduced_form);
