@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #include "operationlist.h"
 #include "coreutilsns.h"
 
-unsigned OperationList::max_size=500;
+unsigned OperationList::max_size {500};
 
 OperationList::OperationList(DatabaseModel *model)
 {
