@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,12 +29,12 @@
 
 class __libcore BehaviorType: public TemplateType<BehaviorType>{
 	private:
-		static QStringList type_names;
+		static const QStringList type_names;
 
 	public:
 		static constexpr unsigned CalledOnNullInput = 1,
-		ReturnsNullOnNullInput = 2,
-		Strict = 3;
+		ReturnsNullOnNullInput = 2;//,
+		//Strict = 3;
 
 		BehaviorType(const QString &type_name);
 		BehaviorType(unsigned type_id);
