@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,10 +18,8 @@
 
 #include "storagetype.h"
 
-QStringList StorageType::type_names =
-{
+const QStringList StorageType::type_names {
 	"", // Reserved for Class::Null
-
 	"plain",
 	"external",
 	"extended",
