@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,12 +19,13 @@
 #include "view.h"
 #include "physicaltable.h"
 
-const QString View::ExtraSCRegExp("((\\;)+(\\s|\\t)*)+$");
+const QString View::ExtraSCRegExp {"((\\;)+(\\s|\\t)*)+$"};
 
 View::View() : BaseTable()
 {
-	obj_type=ObjectType::View;
-	materialized=recursive=with_no_data=false;
+	obj_type = ObjectType::View;
+	materialized = recursive = with_no_data = false;
+	security_invoker = security_barrier = false;
 	attributes[Attributes::Definition]="";
 	attributes[Attributes::References]="";
 	attributes[Attributes::SelectExp]="";
@@ -36,6 +37,10 @@ View::View() : BaseTable()
 	attributes[Attributes::Recursive]="";
 	attributes[Attributes::WithNoData]="";
 	attributes[Attributes::Columns]="";
+	attributes[Attributes::CheckOption]="";
+	attributes[Attributes::Options]="";
+	attributes[Attributes::SecurityBarrier]="";
+	attributes[Attributes::SecurityInvoker]="";
 }
 
 View::~View()
@@ -75,15 +80,25 @@ void View::setProtected(bool value)
 void View::setMaterialized(bool value)
 {
 	setCodeInvalidated(materialized != value);
-	materialized=value;
-	if(materialized) recursive=false;
+	materialized = value;
+
+	if(materialized)
+	{
+		recursive = false;
+		check_option = CheckOptionType::Null;
+	}
 }
 
 void View::setRecursive(bool value)
 {
 	setCodeInvalidated(recursive != value);
-	recursive=value;
-	if(recursive) materialized=false;
+	recursive = value;
+
+	if(recursive)
+	{
+		materialized = false;
+		check_option = CheckOptionType::Null;
+	}
 }
 
 void View::setWithNoData(bool value)
@@ -92,6 +107,32 @@ void View::setWithNoData(bool value)
 	with_no_data=(materialized ? value : false);
 }
 
+void View::setSecurityBarrier(bool value)
+{
+	setCodeInvalidated(security_barrier != value);
+	security_barrier = value;
+}
+
+void View::setSecurityInvoker(bool value)
+{
+	setCodeInvalidated(security_invoker != value);
+	security_invoker = value;
+}
+
+void View::setCheckOption(CheckOptionType check_opt)
+{
+	if(materialized || recursive)
+		check_option = CheckOptionType::Null;
+
+	setCodeInvalidated(check_option != check_opt);
+	check_option = check_opt;
+}
+
+CheckOptionType View::getCheckOption()
+{
+	return check_option;
+}
+
 bool View::isMaterialized()
 {
 	return materialized;
@@ -107,6 +148,16 @@ bool View::isWithNoData()
 	return with_no_data;
 }
 
+bool View::isSecurityInvoker()
+{
+	return security_invoker;
+}
+
+bool View::isSecurityBarrier()
+{
+	return security_barrier;
+}
+
 void View::setReferences(const std::vector<Reference> &obj_refs)
 {
 	this->references = obj_refs;
@@ -266,24 +317,53 @@ bool View::isReferencingTable(BaseTable *tab)
 	return false;
 }
 
+void View::setOptionsAttributes(SchemaParser::CodeType def_type)
+{
+	attribs_map opts_map = {{ Attributes::CheckOption, ~check_option },
+													{ Attributes::SecurityBarrier, security_barrier ? Attributes::True : "" },
+													{ Attributes::SecurityInvoker, security_invoker ? Attributes::True : "" }};
+
+	if(def_type == SchemaParser::SqlCode)
+	{
+		QStringList fmt_opts;
+
+		for(auto &itr : opts_map)
+		{
+			if(!itr.second.isEmpty())
+			{
+				fmt_opts.append(QString("%1=%2")
+												.arg(QString(itr.first).replace('-', '_'), itr.second));
+			}
+		}
+
+		attributes[Attributes::Options] = fmt_opts.join(", ");
+	}
+	else
+	{
+		for(auto &itr : opts_map)
+			attributes[itr.first] = itr.second;
+	}
+}
+
 QString View::getSourceCode(SchemaParser::CodeType def_type)
 {
 	QString code_def=getCachedCode(def_type, false);
 	if(!code_def.isEmpty()) return code_def;
 
-	attributes[Attributes::Materialized]=(materialized ? Attributes::True : "");
-	attributes[Attributes::Recursive]=(recursive ? Attributes::True : "");
-	attributes[Attributes::WithNoData]=(with_no_data ? Attributes::True : "");
-	attributes[Attributes::Columns]="";
-	attributes[Attributes::Tag]="";
+	attributes[Attributes::Materialized] = (materialized ? Attributes::True : "");
+	attributes[Attributes::Recursive] = (recursive ? Attributes::True : "");
+	attributes[Attributes::WithNoData] = (with_no_data ? Attributes::True : "");
+	attributes[Attributes::Columns] = "";
+	attributes[Attributes::Tag] = "";
 	attributes[Attributes::References] = "";
-	attributes[Attributes::Pagination]=(pagination_enabled ? Attributes::True : "");
-	attributes[Attributes::CollapseMode]=QString::number(collapse_mode);
-	attributes[Attributes::AttribsPage]=(pagination_enabled ? QString::number(curr_page[AttribsSection]) : "");
-	attributes[Attributes::ExtAttribsPage]=(pagination_enabled ? QString::number(curr_page[ExtAttribsSection]) : "");
+	attributes[Attributes::Pagination] = (pagination_enabled ? Attributes::True : "");
+	attributes[Attributes::CollapseMode] = QString::number(collapse_mode);
+	attributes[Attributes::AttribsPage] = (pagination_enabled ? QString::number(curr_page[AttribsSection]) : "");
+	attributes[Attributes::ExtAttribsPage] = (pagination_enabled ? QString::number(curr_page[ExtAttribsSection]) : "");
 
 	setSQLObjectAttribute();
 	setLayersAttribute();
+	setOptionsAttributes(def_type);
 
 	if(recursive)
 	{
@@ -323,8 +403,8 @@ QString View::getSourceCode(SchemaParser::CodeType def_type)
 		setFadedOutAttribute();
 
 		attributes[Attributes::Definition] = sql_definition;
-		attributes[Attributes::ZValue]=QString::number(z_value);
-		attributes[Attributes::MaxObjCount]=QString::number(static_cast<unsigned>(getMaxObjectCount() * 1.20));
+		attributes[Attributes::ZValue] = QString::number(z_value);
+		attributes[Attributes::MaxObjCount] = QString::number(static_cast<unsigned>(getMaxObjectCount() * 1.20));
 	}
 
 	return BaseObject::__getSourceCode(def_type);
@@ -770,11 +850,11 @@ std::vector<BaseObject *> View::getObjects(const std::vector<ObjectType> &excl_t
 	return list;
 }
 
-QString View::getDataDictionary(bool split, const attribs_map &extra_attribs)
+QString View::getDataDictionary(bool split, bool md_format, const attribs_map &extra_attribs)
 {
 	attribs_map attribs, aux_attrs;
 	QStringList tab_names, col_names;
-	QString link_dict_file = GlobalAttributes::getSchemaFilePath(GlobalAttributes::DataDictSchemaDir, Attributes::Link);
+	QString link_dict_file = GlobalAttributes::getDictSchemaFilePath(md_format, Attributes::Link);
 
 	attribs.insert(extra_attribs.begin(), extra_attribs.end());
 	attribs[Attributes::Type] = getTypeName();
@@ -804,6 +884,7 @@ QString View::getDataDictionary(bool split, const attribs_map &extra_attribs)
 
 		tab_names.removeDuplicates();
 		attribs[Attributes::References] = tab_names.join(", ");
+		attribs[Attributes::Columns] = "";
 		aux_attrs.clear();
 
 		for(auto &col : gen_columns)
@@ -813,26 +894,24 @@ QString View::getDataDictionary(bool split, const attribs_map &extra_attribs)
 			aux_attrs[Attributes::Type] = col.getType();
 
 			schparser.ignoreUnkownAttributes(true);
-			attribs[Attributes::Columns] += schparser.getSourceCode(GlobalAttributes::getSchemaFilePath(GlobalAttributes::DataDictSchemaDir,
-																																																			BaseObject::getSchemaName(ObjectType::Column)), aux_attrs);
+			attribs[Attributes::Columns] += schparser.getSourceCode(GlobalAttributes::getDictSchemaFilePath(md_format, BaseObject::getSchemaName(ObjectType::Column)), aux_attrs);
 			aux_attrs.clear();
 		}
 
 		for(auto &obj : triggers)
 		{
 			attribs[Attributes::Triggers] +=
-					dynamic_cast<Trigger *>(obj)->getDataDictionary({{ Attributes::Split, attribs[Attributes::Split] }});
+					dynamic_cast<Trigger *>(obj)->getDataDictionary(md_format, {{ Attributes::Split, attribs[Attributes::Split] }});
 		}
 
 		for(auto &obj : indexes)
-			attribs[Attributes::Indexes] +=  dynamic_cast<Index *>(obj)->getDataDictionary();
+			attribs[Attributes::Indexes] +=  dynamic_cast<Index *>(obj)->getDataDictionary(md_format);
 
 		schparser.ignoreUnkownAttributes(true);
-		attribs[Attributes::Objects] += schparser.getSourceCode(GlobalAttributes::getSchemaFilePath(GlobalAttributes::DataDictSchemaDir,
-																																																		Attributes::Objects), attribs);
+		attribs[Attributes::Objects] += schparser.getSourceCode(GlobalAttributes::getDictSchemaFilePath(md_format, Attributes::Objects), attribs);
+
 		schparser.ignoreEmptyAttributes(true);
-		return schparser.getSourceCode(GlobalAttributes::getSchemaFilePath(GlobalAttributes::DataDictSchemaDir,
-																																					 getSchemaName()), attribs);
+		return schparser.getSourceCode(GlobalAttributes::getDictSchemaFilePath(md_format, getSchemaName()), attribs);
 	}
 	catch(Exception &e)
 	{
@@ -853,6 +932,12 @@ QString View::getAlterCode(BaseObject *object)
 	}
 }
 
+bool View::acceptsReplaceCommand()
+{
+	// Materialized views don't accept CREATE OR REPLACE command
+	return !materialized;
+}
+
 void View::updateDependencies()
 {
 	std::vector<BaseObject *> deps;
