@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,15 +27,15 @@
 
 #include "baseobjectwidget.h"
 #include "ui_foreignserverwidget.h"
-#include "widgets/objectstablewidget.h"
+#include "widgets/customtablewidget.h"
 
 class __libgui ForeignServerWidget: public BaseObjectWidget, public Ui::ForeignServerWidget {
-	private:
-		Q_OBJECT
+	Q_OBJECT
 
+	private:
 		ObjectSelectorWidget *fdw_sel;
 
-		ObjectsTableWidget *options_tab;
+		CustomTableWidget *options_tab;
 
 	public:
 		ForeignServerWidget(QWidget * parent = nullptr);
