@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,9 +28,8 @@
 #include "baseobjectwidget.h"
 #include "ui_operatorfamilywidget.h"
 
-class OperatorFamilyWidget: public BaseObjectWidget, public Ui::OperatorFamilyWidget {
-	private:
-		Q_OBJECT
+class __libgui OperatorFamilyWidget: public BaseObjectWidget, public Ui::OperatorFamilyWidget {
+	Q_OBJECT
 
 	public:
 		OperatorFamilyWidget(QWidget * parent = nullptr);
