@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,20 +23,22 @@
 #include "connection.h"
 #include "pgsqlversions.h"
 
-const QStringList ModelsDiffHelper::TableObjsIgnoredAttribs = { Attributes::Alias };
+const QStringList	ModelsDiffHelper::TableObjsIgnoredAttribs { Attributes::Alias };
 
-const QStringList ModelsDiffHelper::ObjectsIgnoredAttribs = {
+const QStringList	ModelsDiffHelper::RolesIgnoredTags {
+		Attributes::AppendedSql,	Attributes::PrependedSql
+};
+
+const QStringList	ModelsDiffHelper::ObjectsIgnoredAttribs {
 	Attributes::MaxObjCount, Attributes::Protected, Attributes::SqlDisabled,
 	Attributes::RectVisible, Attributes::FillColor, Attributes::FadedOut,
 	Attributes::CollapseMode,	Attributes::AttribsPage, Attributes::ExtAttribsPage,
-	Attributes::Pagination,	Attributes::Alias,	Attributes::Layers };
+	Attributes::Pagination,	Attributes::Alias,	Attributes::Layers
+};
 
-const QStringList ModelsDiffHelper::ObjectsIgnoredTags = {
+const QStringList	ModelsDiffHelper::ObjectsIgnoredTags {
 	Attributes::Role, Attributes::Tablespace, Attributes::Collation,
-	Attributes::Position,	Attributes::AppendedSql,	Attributes::PrependedSql };
-
-const QStringList ModelsDiffHelper::RolesIgnoredTags = {
-	Attributes::AppendedSql,	Attributes::PrependedSql
+	Attributes::Position,	Attributes::AppendedSql,	Attributes::PrependedSql
 };
 
 ModelsDiffHelper::ModelsDiffHelper()
@@ -48,8 +50,8 @@ ModelsDiffHelper::ModelsDiffHelper()
 
 	diff_opts[OptKeepClusterObjs]=true;
 	diff_opts[OptCascadeMode]=true;
-	diff_opts[OptForceRecreation]=true;
-	diff_opts[OptRecreateUnmodifiable]=true;
+	diff_opts[OptRecreateUnmodifiable]=false;
+	diff_opts[OptReplaceModified]=false;
 	diff_opts[OptKeepObjectPerms]=true;
 	diff_opts[OptReuseSequences]=true;
 	diff_opts[OptPreserveDbName]=true;
@@ -73,6 +75,59 @@ void ModelsDiffHelper::setDiffOption(DiffOptions opt_id, bool value)
 		diff_opts[opt_id]=value;
 }
 
+void ModelsDiffHelper::setForcedRecreateTypeNames(const QStringList &forced_rec_types)
+{
+	try
+	{
+		std::vector<ObjectType> obj_types;
+
+		for(auto &tp_name : forced_rec_types)
+			obj_types.push_back(BaseObject::getObjectType(tp_name));
+
+		setForcedRecreateTypes(obj_types);
+	}
+	catch(Exception &e)
+	{
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+	}
+}
+
+void ModelsDiffHelper::setForcedRecreateTypes(const std::vector<ObjectType> &forced_rec_types)
+{
+
+	static const std::vector<ObjectType> inv_types {
+		ObjectType::Relationship, ObjectType::Permission,
+		ObjectType::Database, ObjectType::Tag,
+		ObjectType::Textbox, ObjectType::GenericSql,
+		ObjectType::BaseObject, ObjectType::BaseRelationship,
+		ObjectType::BaseTable, ObjectType::TypeAttribute,
+		ObjectType::Parameter
+	};
+
+	for(auto &type : inv_types)
+	{
+		if(std::find(forced_rec_types.begin(), forced_rec_types.end(), type) != forced_rec_types.end())
+		{
+			QString type_name = BaseObject::getSchemaName(type);
+
+			if(type == ObjectType::BaseObject)
+				type_name = QString::number(enum_t(type)) + " " + tr("(unrecognized id)");
+
+			throw Exception(ErrorCode::OprObjectInvalidType,__PRETTY_FUNCTION__,__FILE__,__LINE__, nullptr,
+											tr("Object type id: %1").arg(type_name));
+		}
+	}
+
+	forced_recreate_types = forced_rec_types;
+}
+
+bool ModelsDiffHelper::isForcedRecreateType(ObjectType obj_type)
+{
+	return std::find(forced_recreate_types.begin(),
+									 forced_recreate_types.end(),
+									 obj_type) != forced_recreate_types.end();
+}
+
 void ModelsDiffHelper::setPgSQLVersion(const QString pgsql_ver)
 {
 	this->pgsql_version=pgsql_ver;
@@ -337,7 +392,7 @@ void ModelsDiffHelper::diffTables(PhysicalTable *src_table, PhysicalTable *imp_t
 					 columns created by common relationships will be considered on the comparison. Also,
 					foreign keys are discarded here, since they will be compared on the main comparison
 					at diffModels() */
-				if(aux_obj && diff_type!=ObjectsDiffInfo::DropObject &&
+				if(aux_obj && diff_type != ObjectsDiffInfo::DropObject &&
 						((tab_obj->isAddedByGeneralization() || !tab_obj->isAddedByLinking() ||
 							(aux_obj->getObjectType()==ObjectType::Column && tab_obj->isAddedByLinking())) ||
 						 (constr && constr->getConstraintType()!=ConstraintType::ForeignKey)))
@@ -381,7 +436,7 @@ void ModelsDiffHelper::diffModels(ObjectsDiffInfo::DiffType diff_type)
 		DatabaseModel *aux_model=nullptr;
 		bool objs_differs=false, xml_differs=false;
 
-		if(diff_type==ObjectsDiffInfo::DropObject)
+		if(diff_type == ObjectsDiffInfo::DropObject)
 		{
 			/* For DROP detection, we must gather the objects from the database in order to check
 			 * if they exists on the model. The object drop order here is the inverse of the creation order
@@ -406,38 +461,43 @@ void ModelsDiffHelper::diffModels(ObjectsDiffInfo::DiffType diff_type)
 
 		for(auto &obj_itr : obj_order)
 		{
-			object=obj_itr.second;
-			obj_type=object->getObjectType();
+			object = obj_itr.second;
+			obj_type = object->getObjectType();
 			idx++;
 
 			/* If this checking the following objects are discarded:
 			 * 1) ObjectType::ObjBaseRelationship objects
 			 * 2) Objects which SQL code is disabled or system objects
 			 * 3) Cluster objects such as roles and tablespaces (when the operatoin is DROP and keep_cluster_objs is true) */
-			if(obj_type!=ObjectType::BaseRelationship &&
+			if(obj_type != ObjectType::BaseRelationship &&
 					!object->isSystemObject() && !object->isSQLDisabled() &&
-					((diff_type==ObjectsDiffInfo::DropObject && (!diff_opts[OptKeepClusterObjs] || (diff_opts[OptKeepClusterObjs] && obj_type!=ObjectType::Role && obj_type!=ObjectType::Tablespace))) ||
-					 (diff_type!=ObjectsDiffInfo::DropObject)))
+
+				 ((diff_type == ObjectsDiffInfo::DropObject &&
+						(!diff_opts[OptKeepClusterObjs] ||
+						 (diff_opts[OptKeepClusterObjs] && obj_type != ObjectType::Role && obj_type != ObjectType::Tablespace))) ||
+
+					 (diff_type != ObjectsDiffInfo::DropObject)))
 			{
 				emit s_progressUpdated(prog + ((idx/static_cast<double>(obj_order.size())) * factor),
 															 tr("Processing object `%1' (%2)...").arg(object->getSignature()).arg(object->getTypeName()),
 															 object->getObjectType());
 
 				//Processing objects that are not database, table child object (they are processed further)
-				if(obj_type!=ObjectType::Database && !TableObject::isTableObject(obj_type))
+				if(obj_type != ObjectType::Database && !TableObject::isTableObject(obj_type))
 				{
 					/* Processing permissions. If the operation is DROP and keep_obj_perms is true the
 					 * the permission is ignored */
-					if(obj_type==ObjectType::Permission &&
+					if(obj_type == ObjectType::Permission &&
 
-							((diff_type==ObjectsDiffInfo::DropObject &&
+							((diff_type == ObjectsDiffInfo::DropObject &&
 								!diff_opts[OptKeepObjectPerms]) ||
 
-							 (diff_type==ObjectsDiffInfo::CreateObject &&
+							 (diff_type == ObjectsDiffInfo::CreateObject &&
 								(aux_model->getPermissionIndex(dynamic_cast<Permission *>(object), true) < 0 ||
 								 !diff_opts[OptKeepObjectPerms]))))
+					{
 						generateDiffInfo(diff_type, object);
-
+					}
 					//Processing relationship (in this case only generalization and patitioning ones are considered)
 					else if(obj_type==ObjectType::Relationship)
 					{
@@ -477,22 +537,22 @@ void ModelsDiffHelper::diffModels(ObjectsDiffInfo::DiffType diff_type)
 							}
 						}
 					}
-					else if(obj_type!=ObjectType::Permission)
+					else if(obj_type != ObjectType::Permission)
 					{
 						//Get the object from the database
-						obj_name=object->getSignature();
-						aux_object=aux_model->getObject(obj_name, obj_type);
+						obj_name = object->getSignature();
+						aux_object = aux_model->getObject(obj_name, obj_type);
 
 						//Special case for many-to-many relationships
-						if(obj_type==ObjectType::Table && !aux_object)
-							aux_object=getRelNNTable(obj_name, aux_model);
+						if(obj_type == ObjectType::Table && !aux_object)
+							aux_object = getRelNNTable(obj_name, aux_model);
 
 						if(diff_type != ObjectsDiffInfo::DropObject && aux_object)
 						{
 							/* Try to get a diff from the retrieve object and the current object,
 							 * comparing only basic attributes like schema, tablespace and owner
 							 * this is why the BaseObject::getAlterCode is called */
-							objs_differs=!aux_object->BaseObject::getAlterCode(object).isEmpty();
+							objs_differs = !aux_object->BaseObject::getAlterCode(object).isEmpty();
 
 							//If the objects does not differ, try to compare their XML definition
 							if(!objs_differs)
@@ -507,7 +567,8 @@ void ModelsDiffHelper::diffModels(ObjectsDiffInfo::DiffType diff_type)
 								generateDiffInfo(ObjectsDiffInfo::AlterObject, object, aux_object);
 
 								//If the object is a table, do additional comparision between their child objects
-								if((!diff_opts[OptForceRecreation] || diff_opts[OptRecreateUnmodifiable]) && PhysicalTable::isPhysicalTable(object->getObjectType()))
+								if(!isForcedRecreateType(object->getObjectType()) &&
+									 PhysicalTable::isPhysicalTable(object->getObjectType()))
 								{
 									PhysicalTable *tab=dynamic_cast<PhysicalTable *>(object),
 											*aux_tab=dynamic_cast<PhysicalTable *>(aux_object);
@@ -533,7 +594,7 @@ void ModelsDiffHelper::diffModels(ObjectsDiffInfo::DiffType diff_type)
 				else if(TableObject::isTableObject(obj_type))
 					diffTableObject(dynamic_cast<TableObject *>(object), diff_type);
 				//Comparison between model db and the imported db
-				else if(diff_type==ObjectsDiffInfo::CreateObject)
+				else if(diff_type == ObjectsDiffInfo::CreateObject)
 				{
 					if(!source_model->getAlterCode(imported_model).isEmpty())
 						generateDiffInfo(ObjectsDiffInfo::AlterObject, source_model, imported_model);
@@ -545,9 +606,10 @@ void ModelsDiffHelper::diffModels(ObjectsDiffInfo::DiffType diff_type)
 			else
 			{
 				generateDiffInfo(ObjectsDiffInfo::IgnoreObject, object);
+
 				emit s_progressUpdated(prog + ((idx/static_cast<double>(obj_order.size())) * factor),
-									   tr("Skipping object `%1' (%2)...").arg(object->getSignature()).arg(object->getTypeName()),
-									   object->getObjectType());
+															 tr("Skipping object `%1' (%2)...").arg(object->getSignature(), object->getTypeName()),
+															 object->getObjectType());
 
 				if(diff_canceled)
 					break;
@@ -642,10 +704,11 @@ void ModelsDiffHelper::generateDiffInfo(ObjectsDiffInfo::DiffType diff_type, Bas
 
 			/* If the info is for ALTER and there is a DROP info on the list,
 			 * the object will be recreated instead of modified */
-			if((!diff_opts[OptForceRecreation] || diff_opts[OptRecreateUnmodifiable]) &&
-					diff_type==ObjectsDiffInfo::AlterObject &&
-					isDiffInfoExists(ObjectsDiffInfo::DropObject, old_object, nullptr) &&
-					!isDiffInfoExists(ObjectsDiffInfo::CreateObject, object, nullptr))
+			if((!isForcedRecreateType(object->getObjectType()) ||
+					diff_opts[OptRecreateUnmodifiable]) &&
+				 diff_type == ObjectsDiffInfo::AlterObject &&
+				 isDiffInfoExists(ObjectsDiffInfo::DropObject, old_object, nullptr) &&
+				 !isDiffInfoExists(ObjectsDiffInfo::CreateObject, object, nullptr))
 			{
 				diff_info=ObjectsDiffInfo(ObjectsDiffInfo::CreateObject, object, nullptr);
 				diff_infos.push_back(diff_info);
@@ -748,20 +811,21 @@ void ModelsDiffHelper::generateDiffInfo(ObjectsDiffInfo::DiffType diff_type, Bas
 
 				/* If the info is for DROP, generate the drop for referer objects of the
 				 * one marked to be dropped */
-				if((!diff_opts[OptForceRecreation] || diff_opts[OptRecreateUnmodifiable]) &&
-						diff_type==ObjectsDiffInfo::DropObject)
+				if((isForcedRecreateType(object->getObjectType()) ||
+						diff_opts[OptRecreateUnmodifiable]
+						/* diff_opts[OptReplaceModified] */) &&
+						diff_type == ObjectsDiffInfo::DropObject)
 				{
 					std::vector<BaseObject *> ref_objs;
-					ObjectType obj_type=object->getObjectType();
+					ObjectType obj_type = object->getObjectType();
 
-					//imported_model->getObjectReferences(object, ref_objs);
 					ref_objs = object->getReferences();
 
 					for(auto &obj : ref_objs)
 					{
 						/* Avoiding columns to be dropped when a sequence linked to them is dropped too. This because
-			   a column can be a reference to a sequence so to avoid drop and recreate that column this one
-			   will not be erased, unless the column does not exists in the model anymore */
+						 * a column can be a reference to a sequence so to avoid drop and recreate that column this one
+						 * will not be erased, unless the column does not exists in the model anymore */
 						if((obj_type==ObjectType::Sequence && obj->getObjectType()!=ObjectType::Column) &&
 								(obj_type!=ObjectType::Sequence && obj->getObjectType()!=ObjectType::BaseRelationship))
 							generateDiffInfo(diff_type, obj);
@@ -837,7 +901,7 @@ void ModelsDiffHelper::processDiffInfos()
 		//Separating the base types
 		for(auto &diff : diff_infos)
 		{
-			type=dynamic_cast<Type *>(diff.getObject());
+			type = dynamic_cast<Type *>(diff.getObject());
 
 			if(type && type->getConfiguration()==Type::BaseType)
 			{
@@ -848,96 +912,102 @@ void ModelsDiffHelper::processDiffInfos()
 
 		for(auto &diff : diff_infos)
 		{
-			diff_type=diff.getDiffType();
-			object=diff.getObject();
-			obj_type=object->getObjectType();
-			rel=dynamic_cast<Relationship *>(object);
-			constr=dynamic_cast<Constraint *>(object);
-			col=dynamic_cast<Column *>(object);
+			diff_type = diff.getDiffType();
+			object = diff.getObject();
+			obj_type = object->getObjectType();
+			rel = dynamic_cast<Relationship *>(object);
+			constr = dynamic_cast<Constraint *>(object);
+			col = dynamic_cast<Column *>(object);
 
 			emit s_progressUpdated((idx++/static_cast<double>(diff_infos.size())) * 100,
-								   tr("Processing `%1' info for object `%2' (%3)...")
-								   .arg(diff.getDiffTypeString()).arg(object->getSignature()).arg(object->getTypeName()),
-								   obj_type);
+														 tr("Processing `%1' info for object `%2' (%3)...")
+														 .arg(diff.getDiffTypeString()).arg(object->getSignature()).arg(object->getTypeName()),
+														 obj_type);
 
 			/* Preliminary verification for check constraints: there is the need to
-		 check if the constraint is added by generalization or if this is not the case
-		 if it already exists in a ancestor table of its parent, this avoid the generation
-		 of commands to create or drop an inherited constraint raising errors when export the diff */
-			if(constr && constr->getConstraintType()==ConstraintType::Check)
+			 * check if the constraint is added by generalization or if this is not the case
+			 * if it already exists in a ancestor table of its parent, this avoid the generation
+			 * of commands to create or drop an inherited constraint raising errors when export the diff */
+			if(constr && constr->getConstraintType() == ConstraintType::Check)
 			{
-				parent_tab=dynamic_cast<PhysicalTable *>(constr->getParentTable());
-				skip_obj=constr->isAddedByGeneralization();
+				parent_tab = dynamic_cast<PhysicalTable *>(constr->getParentTable());
+				skip_obj = constr->isAddedByGeneralization();
 
 				for(unsigned i=0; i < parent_tab->getAncestorTableCount() && !skip_obj; i++)
 					skip_obj=(parent_tab->getAncestorTable(i)->getConstraint(constr->getName())!=nullptr);
 
-				if(skip_obj) continue;
+				if(skip_obj)
+					continue;
 			}
 			//Igoring any operation done over inherited columns
 			else if(col)
 			{
-				parent_tab=dynamic_cast<PhysicalTable *>(col->getParentTable());
-				skip_obj=col->isAddedByGeneralization();
+				parent_tab = dynamic_cast<PhysicalTable *>(col->getParentTable());
+				skip_obj = col->isAddedByGeneralization();
 
-				for(unsigned i=0; i < parent_tab->getAncestorTableCount() && !skip_obj; i++)
+				for(unsigned i = 0; i < parent_tab->getAncestorTableCount() && !skip_obj; i++)
 				{
-					aux_col=parent_tab->getAncestorTable(i)->getColumn(col->getName());
-					skip_obj=(aux_col && aux_col->getType().getAliasType()==col->getType());
+					aux_col = parent_tab->getAncestorTable(i)->getColumn(col->getName());
+					skip_obj = (aux_col && aux_col->getType().getAliasType() == col->getType());
 				}
 
-				if(skip_obj) continue;
+				if(skip_obj)
+					continue;
 			}
 
 			//Generating the DROP commands
-			if(diff_type==ObjectsDiffInfo::DropObject)
+			if(diff_type == ObjectsDiffInfo::DropObject)
 			{
-				if(rel && (rel->getRelationshipType()==BaseRelationship::RelationshipGen ||
-									 rel->getRelationshipType()==BaseRelationship::RelationshipPart))
+				if(rel && (rel->getRelationshipType() == BaseRelationship::RelationshipGen ||
+									 rel->getRelationshipType() == BaseRelationship::RelationshipPart))
 				{
 					//Undoing inheritances
 					no_inherit_def+=rel->getAlterRelationshipDefinition(true);
 				}
-				else if(obj_type==ObjectType::Permission)
+				else if(obj_type == ObjectType::Permission)
+				{
 					//Unsetting permissions
-					unset_perms+=object->getDropCode(diff_opts[OptCascadeMode]);
+					unset_perms += object->getDropCode(diff_opts[OptCascadeMode]);
+				}
 				else
 				{
 					//Ordinary drop commands for any object except columns
-					if(obj_type!=ObjectType::Column)
-						drop_objs[object->getObjectId()]=getSourceCode(object, true);
+					if(obj_type != ObjectType::Column)
+						drop_objs[object->getObjectId()] = getSourceCode(object, true);
 					else
 					{
 						/* Special case for columns: due to cases like inheritance there is the
-			   the need to drop the columns in the normal order of creation to avoid
-			   error like 'drop inherited column' or wrong propagation of drop on all
-			   child tables. */
+						 * the need to drop the columns in the normal order of creation to avoid
+						 * error like 'drop inherited column' or wrong propagation of drop on all
+						 * child tables. */
 						drop_cols.push_back(object);
 					}
 				}
 			}
 			//Generating the CREATE commands
-			else if(diff_type==ObjectsDiffInfo::CreateObject)
+			else if(diff_type == ObjectsDiffInfo::CreateObject)
 			{
-				if(rel && (rel->getRelationshipType()==BaseRelationship::RelationshipGen ||
-									 rel->getRelationshipType()==BaseRelationship::RelationshipPart))
+				if(rel && (rel->getRelationshipType() == BaseRelationship::RelationshipGen ||
+									 rel->getRelationshipType() == BaseRelationship::RelationshipPart))
 				{
 					//Creating inheritances
-					inherit_def+=rel->getAlterRelationshipDefinition(false);
+					inherit_def += rel->getAlterRelationshipDefinition(false);
 				}
-				else if(obj_type==ObjectType::Permission)
+				else if(obj_type == ObjectType::Permission)
+				{
 					//Setting permissions
-					set_perms+=object->getSourceCode(SchemaParser::SqlCode);
+					set_perms += object->getSourceCode(SchemaParser::SqlCode);
+				}
 				else
 				{
 					/* Special case for constaints: the creation commands for these objects are appended at the very end of create commands secion.
 						Primary keys, unique keys, check constraints and exclude constraints are created after foreign keys */
-					if(object->getObjectType()==ObjectType::Constraint)
+					if(object->getObjectType() == ObjectType::Constraint)
 					{
 						Constraint *constr = dynamic_cast<Constraint *>(object);
 
 						if(constr->getConstraintType() == ConstraintType::ForeignKey)
-							create_fks[constr->getObjectId()]=getSourceCode(constr, false);
+							create_fks[constr->getObjectId()] = getSourceCode(constr, false);
 						// We only create a constraint if the parent is not being created
 						else if(create_objs.count(constr->getParentTable()->getObjectId()) == 0 ||
 									 /* Special case for unique constraints: in a very specific scenario, when diff against an empty database,
@@ -946,67 +1016,79 @@ void ModelsDiffHelper::processDiffInfos()
 										* ALTER TABLE command. */
 										(create_objs.count(constr->getParentTable()->getObjectId()) &&
 										 constr->isReferRelationshipAddedColumns() && constr->getConstraintType() == ConstraintType::Unique))
-							create_constrs[constr->getObjectId()]=getSourceCode(constr, false);
+							create_constrs[constr->getObjectId()] = getSourceCode(constr, false);
 					}
 					else
 					{
-						create_objs[object->getObjectId()]=getSourceCode(object, false);
+						create_objs[object->getObjectId()] = getSourceCode(object, false);
 
-						if(obj_type==ObjectType::Schema)
+						if(obj_type == ObjectType::Schema)
 							sch_names.push_back(object->getName(true));
 					}
 				}
 			}
 			//Generating the ALTER commands
-			else if(diff_type==ObjectsDiffInfo::AlterObject)
+			else if(diff_type == ObjectsDiffInfo::AlterObject)
 			{
-				//Recreating the object instead of generating an ALTER command for it
-				if((diff_opts[OptForceRecreation] && obj_type!=ObjectType::Database) &&
-						(!diff_opts[OptRecreateUnmodifiable] ||
-						 (diff_opts[OptRecreateUnmodifiable] && !object->acceptsAlterCommand() &&
-						  diff.getObject()->getSourceCode(SchemaParser::SqlCode).simplified()!=
-						  diff.getOldObject()->getSourceCode(SchemaParser::SqlCode).simplified())))
+				QString obj_sql, old_obj_sql;
+				bool is_forced_create = isForcedRecreateType(object->getObjectType()),
+						 is_recreate_unmod = diff_opts[OptRecreateUnmodifiable] && !object->acceptsAlterCommand(),
+						 is_replace_mod = diff_opts[OptReplaceModified] && object->acceptsReplaceCommand();
+
+				obj_sql = diff.getObject()->getSourceCode(SchemaParser::SqlCode).simplified();
+				old_obj_sql = diff.getOldObject()->getSourceCode(SchemaParser::SqlCode).simplified();
+
+				// If one or more options that controls the recreation of objects is set
+				if(obj_type != ObjectType::Database && obj_sql != old_obj_sql &&
+						(is_forced_create || is_recreate_unmod || is_replace_mod))
 				{
-					recreateObject(object, drop_vect, create_vect);
-
-					//Generating the drop for the object's reference
-					for(auto &obj : drop_vect)
-						drop_objs[obj->getObjectId()]=getSourceCode(obj, true);
-
-					//Generating the create for the object's reference
-					for(auto &obj : create_vect)
+					// Replacing objects that accepts CREATE OR REPLACE
+					if(is_replace_mod)
+						alter_objs[object->getObjectId()] = getSourceCode(object, false);
+					// Recreating objects via DROP and CREATE
+					else if(is_recreate_unmod || is_forced_create)
 					{
-						//The there is no ALTER info registered for an object's reference
-						if(!isDiffInfoExists(ObjectsDiffInfo::AlterObject, nullptr, obj, false))
-						{
-							/* Special case for constraints, their code will be appeded to a separated variable in order to
-							 create them at the end of diff buffer */
-							if(obj->getObjectType()==ObjectType::Constraint)
-							{
-								if(dynamic_cast<Constraint *>(obj)->getConstraintType()==ConstraintType::ForeignKey)
-									create_fks[obj->getObjectId()]=getSourceCode(obj, false);
-								else
-									create_constrs[obj->getObjectId()]=getSourceCode(obj, false);
-							}
-							else
-								create_objs[obj->getObjectId()]=getSourceCode(obj, false);
-						}
-					}
+						recreateObject(object, drop_vect, create_vect);
 
-					drop_vect.clear();
-					create_vect.clear();
+						//Generating the drop for the object's reference
+						for(auto &obj : drop_vect)
+							drop_objs[obj->getObjectId()] = getSourceCode(obj, true);
+
+						//Generating the create for the object's reference
+						for(auto &obj : create_vect)
+						{
+							//The there is no ALTER info registered for an object's reference
+							if(!isDiffInfoExists(ObjectsDiffInfo::AlterObject, nullptr, obj, false))
+							{
+								/* Special case for constraints, their code will be appeded to a separated variable in order to
+								 create them at the end of diff buffer */
+								if(obj->getObjectType()==ObjectType::Constraint)
+								{
+									if(dynamic_cast<Constraint *>(obj)->getConstraintType()==ConstraintType::ForeignKey)
+										create_fks[obj->getObjectId()] = getSourceCode(obj, false);
+									else
+										create_constrs[obj->getObjectId()] = getSourceCode(obj, false);
+								}
+								else
+									create_objs[obj->getObjectId()] = getSourceCode(obj, false);
+							}
+						}
+
+						drop_vect.clear();
+						create_vect.clear();
+					}
 				}
 				else
 				{
 					if(diff.getOldObject())
-						alter_def=diff.getOldObject()->getAlterCode(object);
+						alter_def = diff.getOldObject()->getAlterCode(object);
 
 					if(obj_type == ObjectType::Database && diff_opts[OptPreserveDbName])
 						alter_def.remove(QRegularExpression(QString("(ALTER)( )+(DATABASE)( )+(%1)( )+(RENAME)( )+(TO)(.)*(\\n)")
 																								.arg(diff.getOldObject()->getSignature()), QRegularExpression::DotMatchesEverythingOption));
 
 					if(!alter_def.isEmpty())
-						alter_objs[object->getObjectId()]=alter_def;
+						alter_objs[object->getObjectId()] = alter_def;
 				}
 			}
 		}
@@ -1201,7 +1283,6 @@ void ModelsDiffHelper::recreateObject(BaseObject *object, std::vector<BaseObject
 		}
 
 		//Get all references to the retrieved object on the database
-		//imported_model->getObjectReferences(aux_obj, ref_objs, false, true);
 		ref_objs = aux_obj->getReferences(false, { ObjectType::Permission });
 
 		/* If the to-be recreate object is a constraint check if it's a pk,
@@ -1235,12 +1316,12 @@ void ModelsDiffHelper::recreateObject(BaseObject *object, std::vector<BaseObject
 		}
 
 		/* Register a drop info for the object only if there is no drop registered previously,
-	   avoiding multiple drop statments for the same object */
+		 avoiding multiple drop statments for the same object */
 		if(aux_obj && !isDiffInfoExists(ObjectsDiffInfo::DropObject, aux_obj, nullptr))
 			drop_objs.push_back(aux_obj);
 
 		/* Register a create info for the object only if there is no drop or create registered previously,
-	   avoiding wrongly recreating the object */
+		 avoiding wrongly recreating the object */
 		if(!isDiffInfoExists(ObjectsDiffInfo::DropObject, aux_obj, nullptr) &&
 				!isDiffInfoExists(ObjectsDiffInfo::CreateObject, aux_obj, nullptr))
 			create_objs.push_back(object);
