@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,6 +34,11 @@ void SQLExecutionHelper::setCommand(const QString &cmd)
 	command = cmd;
 }
 
+QString SQLExecutionHelper::getCommand()
+{
+	return command;
+}
+
 ResultSetModel *SQLExecutionHelper::getResultSetModel()
 {
 	return result_model;
