@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,8 +20,8 @@
 #include "tools/databaseimportform.h"
 #include "guiutilsns.h"
 #include "settings/generalconfigwidget.h"
-#include "objectstablewidget.h"
-#include "objectfinderwidget.h"
+#include "customtablewidget.h"
+#include <QScrollBar>
 
 ModelObjectsWidget::ModelObjectsWidget(bool simplified_view, QWidget *parent) : QWidget(parent)
 {
@@ -41,65 +41,75 @@ ModelObjectsWidget::ModelObjectsWidget(bool simplified_view, QWidget *parent) :
 	options_tb->setVisible(!simplified_view);
 	visibleobjects_grp->setVisible(false);
 	filter_wgt->setVisible(simplified_view);
-	splitter->handle(1)->setEnabled(false);
 
 	connect(objectstree_tw, &QTreeWidget::itemPressed, this, &ModelObjectsWidget::selectObject);
 	connect(objectstree_tw, &QTreeWidget::itemPressed, this, &ModelObjectsWidget::showObjectMenu);
-	connect(objectslist_tbw, &QTableWidget::itemPressed, this, &ModelObjectsWidget::selectObject);
-	connect(objectslist_tbw, &QTableWidget::itemPressed, this, &ModelObjectsWidget::showObjectMenu);
-	connect(objectstree_tw, &QTreeWidget::itemSelectionChanged, this, &ModelObjectsWidget::selectObject);
-	connect(objectslist_tbw, &QTableWidget::itemSelectionChanged, this, &ModelObjectsWidget::selectObject);
-	connect(expand_all_tb, &QToolButton::clicked, objectstree_tw, &QTreeWidget::expandAll);
-	connect(collapse_all_tb, &QToolButton::clicked, this, &ModelObjectsWidget::collapseAll);
+	//connect(objectstree_tw, &QTreeWidget::itemSelectionChanged, this, &ModelObjectsWidget::selectObject);
+
+	connect(objectstree_tw, &QTreeWidget::itemCollapsed, this, [this](){
+		objectstree_tw->resizeColumnToContents(0);
+	});
+
+	connect(objectstree_tw, &QTreeWidget::itemExpanded, this, [this](){
+		objectstree_tw->resizeColumnToContents(0);
+	});
+
+	connect(expand_all_tb, &QToolButton::clicked,  this, [this](){
+		objectstree_tw->blockSignals(true);
+		objectstree_tw->expandAll();
+		objectstree_tw->blockSignals(false);
+		objectstree_tw->resizeColumnToContents(0);
+	});
+
+	connect(collapse_all_tb, &QToolButton::clicked,  this, [this](){
+		objectstree_tw->blockSignals(true);
+		objectstree_tw->collapseAll();
+		objectstree_tw->blockSignals(false);
+		objectstree_tw->resizeColumnToContents(0);
+	});
 
 	if(!simplified_view)
 	{
 		obj_types_wgt = new ObjectTypesListWidget(this);
 		visibleobjects_grp->layout()->addWidget(obj_types_wgt);
 
-		widgets_conf.setValue(QString("splitterSize"), splitter->saveState());
 		connect(options_tb, &QToolButton::clicked,this, &ModelObjectsWidget::changeObjectsView);
 
-		connect(obj_types_wgt, &ObjectTypesListWidget::s_typeCheckStateChanged, [this](ObjectType obj_type, Qt::CheckState state) {
+		connect(obj_types_wgt, &ObjectTypesListWidget::s_typeCheckStateChanged, this, [this](ObjectType obj_type, Qt::CheckState state) {
 			setObjectVisible(obj_type, state == Qt::Checked);
 			updateObjectsView();
 		});
 
-		connect(obj_types_wgt, &ObjectTypesListWidget::s_typesCheckStateChanged, [this](Qt::CheckState state) {
+		connect(obj_types_wgt, &ObjectTypesListWidget::s_typesCheckStateChanged, this, [this](Qt::CheckState state) {
 			setAllObjectsVisible(state == Qt::Checked);
 		});
 
 		connect(objectstree_tw, &QTreeWidget::itemDoubleClicked, this, &ModelObjectsWidget::editObject);
-		connect(objectslist_tbw, &QTableWidget::itemDoubleClicked, this, &ModelObjectsWidget::editObject);
 		connect(hide_tb, &QToolButton::clicked, this, &ModelObjectsWidget::hide);
 
-		setAllObjectsVisible(true);
-		objectslist_tbw->installEventFilter(this);
+		setAllObjectsVisible(true);	
 		objectstree_tw->installEventFilter(this);
-		objectslist_tbw->setSelectionMode(QAbstractItemView::ExtendedSelection);
 		objectstree_tw->setSelectionMode(QAbstractItemView::ExtendedSelection);
 	}
 	else
 	{
+		model_objs_grid->setContentsMargins(GuiUtilsNs::LtMargin, GuiUtilsNs::LtMargin,
+																				GuiUtilsNs::LtMargin, GuiUtilsNs::LtMargin);
 		setMinimumSize(250, 300);
-		setWindowModality(Qt::ApplicationModal);
 		setWindowFlags(Qt::Dialog | Qt::WindowCloseButtonHint | Qt::WindowTitleHint);
+		setWindowModality(Qt::ApplicationModal);
 		connect(objectstree_tw, &QTreeWidget::itemDoubleClicked, this, &ModelObjectsWidget::close);
-		connect(objectslist_tbw, &QTableWidget::itemDoubleClicked, this, &ModelObjectsWidget::close);
 		connect(select_tb, &QToolButton::clicked, this, &ModelObjectsWidget::close);
 		connect(cancel_tb, &QToolButton::clicked, this, &ModelObjectsWidget::close);
 	}
 
-	connect(tree_view_tb, &QToolButton::clicked, this, &ModelObjectsWidget::changeObjectsView);
-	connect(list_view_tb, &QToolButton::clicked, this, &ModelObjectsWidget::changeObjectsView);
 	connect(filter_edt, &QLineEdit::textChanged, this, &ModelObjectsWidget::filterObjects);
 	connect(by_id_chk, &QCheckBox::toggled, this, &ModelObjectsWidget::filterObjects);
 }
 
 bool ModelObjectsWidget::eventFilter(QObject *object, QEvent *event)
 {
-	if(event->type() == QEvent::FocusOut &&
-		 (object==objectslist_tbw || object==objectstree_tw))
+	if(event->type() == QEvent::FocusOut && object==objectstree_tw)
 	{
 		QFocusEvent *evnt=dynamic_cast<QFocusEvent *>(event);
 
@@ -123,13 +133,31 @@ void ModelObjectsWidget::hide()
 	emit s_visibilityChanged(false);
 }
 
+void ModelObjectsWidget::show()
+{
+	QWidget::show();
+
+	/* When in simplified view we use an event loop to block the execution in
+	 * the show event until the user takes an action in the widget that
+	 * causes its closing */
+	if(simplified_view)
+	{
+		connect(this, qOverload<BaseObject *, bool>(&ModelObjectsWidget::s_visibilityChanged), this, [this](BaseObject *, bool visible) {
+			if(!visible)
+				event_loop.quit();
+		});
+
+		event_loop.exec();
+	}
+}
 
 void ModelObjectsWidget::showObjectMenu()
 {
-	if(!selected_objs.empty() && QApplication::mouseButtons()==Qt::RightButton && model_wgt && !simplified_view)
+	if(!selected_objs.empty() &&
+		 QApplication::mouseButtons()==Qt::RightButton &&
+		 model_wgt && !simplified_view)
 	{
 		model_wgt->showObjectMenu();
-		clearSelectedObject();
 	}
 }
 
@@ -140,18 +168,8 @@ void ModelObjectsWidget::editObject()
 		//If the user double-clicked the item "Permission (n)" on tree view
 		if(sender()==objectstree_tw && objectstree_tw->currentItem() &&
 			 objectstree_tw->currentItem()->data(1, Qt::UserRole).toUInt() == enum_t(ObjectType::Permission))
-			model_wgt->showObjectForm(ObjectType::Permission, reinterpret_cast<BaseObject *>(objectstree_tw->currentItem()->data(0, Qt::UserRole).value<void *>()));
+			model_wgt->showObjectForm(ObjectType::Permission, getTreeItemData(objectstree_tw->currentItem()));
 		//If the user double-clicked a permission on  list view
-		else if(sender() == objectslist_tbw && objectslist_tbw->currentRow() >= 0)
-		{
-			BaseObject *obj=reinterpret_cast<Permission *>(objectslist_tbw->item(objectslist_tbw->currentRow(), 0)->data(Qt::UserRole).value<void *>());
-			Permission *perm=dynamic_cast<Permission *>(obj);
-
-			if(perm)
-				model_wgt->showObjectForm(ObjectType::Permission, perm->getObject());
-			else
-			  model_wgt->editObject();
-		}
 		else
 			model_wgt->editObject();
 
@@ -164,94 +182,95 @@ void ModelObjectsWidget::selectObject()
 	BaseObject *selected_obj = nullptr;
 	ObjectType obj_type = ObjectType::BaseObject;
 	ModelWidget *model_wgt = nullptr;
-
-	selected_objs.clear();
+	QList<QTreeWidgetItem *> sel_items = objectstree_tw->selectedItems();
 
 	if(!simplified_view && this->model_wgt)
 		model_wgt = this->model_wgt;
 	else if(simplified_view)
 		model_wgt = db_model->getModelWidget();
 
-	if(tree_view_tb->isChecked())
+	selected_objs.clear();
+	QTreeWidgetItem *tree_item = objectstree_tw->currentItem();
+
+	if(tree_item)
 	{
-		QTreeWidgetItem *tree_item = objectstree_tw->currentItem();
+		obj_type = static_cast<ObjectType>(tree_item->data(1, Qt::UserRole).toUInt());
 
-		if(tree_item)
+		for(auto &item : sel_items)
 		{
-			obj_type = static_cast<ObjectType>(tree_item->data(1,Qt::UserRole).toUInt());
-			selected_obj = reinterpret_cast<BaseObject *>(tree_item->data(0,Qt::UserRole).value<void *>());
+			selected_obj = getTreeItemData(item);
 
-			for(auto &item : objectstree_tw->selectedItems())
-			{
-				selected_obj = reinterpret_cast<BaseObject *>(item->data(0,Qt::UserRole).value<void *>());
-
-				if(selected_obj)
-					selected_objs.push_back(selected_obj);
-			}
-		}
-
-		//If user select a group item popups a "New [OBJECT]" menu
-		if((!simplified_view || (simplified_view && enable_obj_creation)) &&
-				!selected_obj && QApplication::mouseButtons() == Qt::RightButton &&
-				obj_type != ObjectType::Column && obj_type != ObjectType::Constraint && obj_type != ObjectType::Rule &&
-				obj_type != ObjectType::Index && obj_type != ObjectType::Trigger && obj_type != ObjectType::Permission)
-		{
-			QAction act, *p_act = nullptr;
-			QMenu popup;
-
-			//If not a relationship, connect the action to the addNewObject method of the model wiget
-			if(obj_type != ObjectType::Relationship)
-			{
-				act.setData(QVariant(enum_t(obj_type)));
-				p_act = &act;
-				connect(p_act, &QAction::triggered, model_wgt, &ModelWidget::addNewObject);
-			}
-			//Case is a relationship, insert the relationship menu of the model wiget into the action
-			else
-				p_act = model_wgt->rels_menu->menuAction();
-
-			if(simplified_view && enable_obj_creation)
-				connect(model_wgt->getDatabaseModel(), &DatabaseModel::s_objectAdded, this, &ModelObjectsWidget::selectCreatedObject, Qt::QueuedConnection);
-
-			p_act->setIcon(QPixmap(GuiUtilsNs::getIconPath(obj_type)));
-			p_act->setText(tr("New") + QString(" ") + BaseObject::getTypeName(obj_type));
-			popup.addAction(p_act);
-			popup.exec(QCursor::pos());
-			disconnect(p_act, nullptr, model_wgt, nullptr);
-			disconnect(model_wgt->getDatabaseModel(), nullptr, this, nullptr);
+			if(selected_obj)
+				selected_objs.push_back(selected_obj);
 		}
 	}
-	else
+
+	//If user select a group item popups a "New [OBJECT]" menu
+	if((!simplified_view || (simplified_view && enable_obj_creation)) &&
+			selected_objs.empty() && QApplication::mouseButtons() == Qt::RightButton &&
+			obj_type != ObjectType::Column && obj_type != ObjectType::Constraint && obj_type != ObjectType::Rule &&
+			obj_type != ObjectType::Index && obj_type != ObjectType::Trigger && obj_type != ObjectType::Permission)
 	{
-		QTableWidgetItem *tab_item=objectslist_tbw->item(objectslist_tbw->currentRow(), 0);
+		QAction act, *p_act = nullptr;
+		QMenu popup;
 
-		if(tab_item)
+		//If not a relationship, connect the action to the addNewObject method of the model wiget
+		if(obj_type != ObjectType::Relationship)
 		{
-			selected_obj = reinterpret_cast<BaseObject *>(tab_item->data(Qt::UserRole).value<void *>());
-			obj_type = selected_obj->getObjectType();
-
-			for(auto &item : objectslist_tbw->selectedItems())
-			{
-				if(item->column() !=0 )
-					continue;
-
-				selected_obj = reinterpret_cast<BaseObject *>(item->data(Qt::UserRole).value<void *>());
-
-				if(selected_obj)
-					selected_objs.push_back(selected_obj);
-			}
+			act.setData(QVariant(enum_t(obj_type)));
+			p_act = &act;
+			connect(p_act, &QAction::triggered, model_wgt, &ModelWidget::addNewObject);
 		}
+		//Case is a relationship, insert the relationship menu of the model wiget into the action
+		else
+			p_act = model_wgt->rels_menu->menuAction();
+
+		if(simplified_view && enable_obj_creation)
+			connect(model_wgt->getDatabaseModel(), &DatabaseModel::s_objectAdded, this, &ModelObjectsWidget::selectCreatedObject, Qt::QueuedConnection);
+
+		p_act->setIcon(QIcon(GuiUtilsNs::getIconPath(obj_type)));
+		p_act->setText(tr("New") + " " + BaseObject::getTypeName(obj_type));
+		popup.addAction(p_act);
+		popup.exec(QCursor::pos());
+		disconnect(p_act, nullptr, model_wgt, nullptr);
+		disconnect(model_wgt->getDatabaseModel(), nullptr, this, nullptr);
 	}
 
 	if(obj_type != ObjectType::Permission && !selected_objs.empty() && !simplified_view)
 	{
+		model_wgt->scene->blockSignals(true);
 		model_wgt->scene->clearSelection();
+		model_wgt->scene->blockSignals(false);
+
+		/* If the user has selected only one graphical object in the tree and is holding
+		 * Alt key then the object will be highlighted in the canvas */
+		if(selected_objs.size() == 1 && qApp->keyboardModifiers() == Qt::AltModifier)
+		{
+			BaseGraphicObject *graph_obj = dynamic_cast<BaseGraphicObject *>(selected_objs.at(0));
+
+			if(!graph_obj)
+				return;
+
+			QGraphicsItem *scn_item = dynamic_cast<QGraphicsItem *>(graph_obj->getOverlyingObject());
+
+			scn_item->setSelected(true);
+			model_wgt->scene->views().at(0)->centerOn(scn_item);
+		}
+
 		model_wgt->configurePopupMenu(selected_objs);
 		model_wgt->emitSceneInteracted();
 	}
 }
 
-QVariant ModelObjectsWidget::generateItemValue(BaseObject *object)
+BaseObject *ModelObjectsWidget::getTreeItemData(QTreeWidgetItem *item)
+{
+ if(!item)
+	 return nullptr;
+
+ return reinterpret_cast<BaseObject *>(item->data(0,Qt::UserRole).value<void *>());
+}
+
+QVariant ModelObjectsWidget::generateItemData(BaseObject *object)
 {
 	return QVariant::fromValue(reinterpret_cast<void *>(object));
 }
@@ -260,9 +279,6 @@ QTreeWidgetItem *ModelObjectsWidget::createItemForObject(BaseObject *object, QTr
 {
 	QTreeWidgetItem *item=nullptr;
 	QFont font;
-	QString str_aux;
-	BaseRelationship::RelType rel_type;
-	ConstraintType constr_type;
 	ObjectType obj_type;
 	TableObject *tab_obj=nullptr;
 	QString obj_name;
@@ -274,12 +290,12 @@ QTreeWidgetItem *ModelObjectsWidget::createItemForObject(BaseObject *object, QTr
 	tab_obj=dynamic_cast<TableObject *>(object);
 	item=new QTreeWidgetItem(root);
 
-	if(obj_type==ObjectType::Function)
+	if(BaseFunction::isBaseFunction(obj_type))
 	{
-		Function *func=dynamic_cast<Function *>(object);
+		BaseFunction *func = dynamic_cast<BaseFunction *>(object);
 		func->createSignature(false);
 		item->setText(0,func->getSignature());
-		obj_name=func->getSignature();
+		obj_name = func->getSignature();
 		func->createSignature(true);
 	}
 	else if(obj_type==ObjectType::Operator)
@@ -291,7 +307,7 @@ QTreeWidgetItem *ModelObjectsWidget::createItemForObject(BaseObject *object, QTr
 	else if(obj_type==ObjectType::OpClass || obj_type == ObjectType::OpFamily)
 	{
 		obj_name=object->getSignature(false);
-		obj_name.replace(QRegularExpression("( )+(USING)( )+"), QString(" ["));
+		obj_name.replace(QRegularExpression("( )+(USING)( )+"), " [");
 		obj_name+=QChar(']');
 		item->setText(0,obj_name);
 	}
@@ -302,8 +318,8 @@ QTreeWidgetItem *ModelObjectsWidget::createItemForObject(BaseObject *object, QTr
 	}
 
 	item->setToolTip(0, QString("%1 (id: %2)").arg(obj_name).arg(object->getObjectId()));
-	item->setData(0, Qt::UserRole, generateItemValue(object));
-	item->setText(1, QString::number(object->getObjectId()));
+	item->setData(0, Qt::UserRole, generateItemData(object));
+	item->setData(2, Qt::UserRole, QString("%1_%2").arg(object->getObjectId()).arg(object->getSchemaName()));
 
 	if(update_perms)
 		updatePermissionTree(item, object);
@@ -314,55 +330,25 @@ QTreeWidgetItem *ModelObjectsWidget::createItemForObject(BaseObject *object, QTr
 	if(tab_obj && tab_obj->isAddedByRelationship())
 	{
 		font.setItalic(true);
-		item->setForeground(0, ObjectsTableWidget::getTableItemColor(ObjectsTableWidget::RelAddedItemAltFgColor));
+		item->setForeground(0, CustomTableWidget::getTableItemColor(CustomTableWidget::RelAddedItemAltFgColor));
 	}
 	else if(object->isProtected() || object->isSystemObject())
 	{
 		font.setItalic(true);
-		item->setForeground(0, ObjectsTableWidget::getTableItemColor(ObjectsTableWidget::ProtItemAltFgColor));
+		item->setForeground(0, CustomTableWidget::getTableItemColor(CustomTableWidget::ProtItemAltFgColor));
 	}
 
 	item->setFont(0,font);
 
-	if(obj_type==ObjectType::BaseRelationship || obj_type==ObjectType::Relationship)
-	{
-		rel_type=dynamic_cast<BaseRelationship *>(object)->getRelationshipType();
+	int sub_type = -1;
 
-		if(obj_type==ObjectType::BaseRelationship)
-		{
-			if(rel_type==BaseRelationship::RelationshipFk)
-				str_aux=QString("fk");
-			else
-				str_aux=QString("tv");
-		}
-		else if(rel_type==BaseRelationship::Relationship11)
-			str_aux=QString("11");
-		else if(rel_type==BaseRelationship::Relationship1n)
-			str_aux=QString("1n");
-		else if(rel_type==BaseRelationship::RelationshipNn)
-			str_aux=QString("nn");
-		else if(rel_type==BaseRelationship::RelationshipDep)
-			str_aux=QString("dep");
-		else if(rel_type==BaseRelationship::RelationshipGen)
-			str_aux=QString("gen");
-	}
-	else if(obj_type==ObjectType::Constraint)
-	{
-		constr_type=dynamic_cast<Constraint *>(object)->getConstraintType();
+	if(obj_type == ObjectType::BaseRelationship || obj_type == ObjectType::Relationship)
+		sub_type = dynamic_cast<BaseRelationship *>(object)->getRelationshipType();
+	else if(obj_type == ObjectType::Constraint)
+		sub_type = dynamic_cast<Constraint *>(object)->getConstraintType().getTypeId();
 
-		if(constr_type==ConstraintType::PrimaryKey)
-			str_aux=QString("_%1").arg(TableObjectView::TextPrimaryKey);
-		else if(constr_type==ConstraintType::ForeignKey)
-			str_aux=QString("_%1").arg(TableObjectView::TextForeignKey);
-		else if(constr_type==ConstraintType::Check)
-			str_aux=QString("_%1").arg(TableObjectView::TextCheck);
-		else if(constr_type==ConstraintType::Unique)
-			str_aux=QString("_%1").arg(TableObjectView::TextUnique);
-		else if(constr_type==ConstraintType::Exclude)
-			str_aux=QString("_%1").arg(TableObjectView::TextExclude);
-	}
-
-	item->setIcon(0, QPixmap(GuiUtilsNs::getIconPath(BaseObject::getSchemaName(obj_type) + str_aux)));
+	item->setIcon(0, QIcon(GuiUtilsNs::getIconPath(obj_type, sub_type)));
+	item->setData(2, Qt::UserRole, QString("%1_%2").arg(object->getObjectId()).arg(object->getSchemaName()));
 
 	return item;
 }
@@ -402,26 +388,14 @@ void ModelObjectsWidget::setAllObjectsVisible(bool value)
 
 void ModelObjectsWidget::changeObjectsView()
 {
-	if(sender()==tree_view_tb || sender()==list_view_tb)
-	{
-		visaoobjetos_stw->setCurrentIndex(sender()==tree_view_tb ? 0 : 1);
-		tree_view_tb->setChecked(sender()==tree_view_tb);
-		list_view_tb->setChecked(sender()==list_view_tb);
-		by_id_chk->setEnabled(sender()==tree_view_tb);
-	}
-	else if(sender()==options_tb)
+	if(sender()==options_tb)
 	{
 		filter_wgt->setVisible(options_tb->isChecked());
 		visibleobjects_grp->setVisible(options_tb->isChecked());
-		splitter->handle(1)->setEnabled(options_tb->isChecked());
-
-		//Restore the splitter state if the options toolbutton is not toggled
-		if(!options_tb->isChecked())
-			splitter->restoreState(widgets_conf.value(QString("splitterSize")).toByteArray());
 	}
 
-	expand_all_tb->setEnabled(tree_view_tb->isChecked());
-	collapse_all_tb->setEnabled(tree_view_tb->isChecked());
+	expand_all_tb->setEnabled(true);
+	collapse_all_tb->setEnabled(true);
 }
 
 void ModelObjectsWidget::collapseAll()
@@ -435,59 +409,18 @@ void ModelObjectsWidget::collapseAll()
 
 void ModelObjectsWidget::filterObjects()
 {
-	if(tree_view_tb->isChecked())
-	{
-		DatabaseImportForm::filterObjects(objectstree_tw, filter_edt->text(), (by_id_chk->isChecked() ? 1 : 0), simplified_view);
-	}
-	else
-	{
-		QList<QTableWidgetItem*> items=objectslist_tbw->findItems(filter_edt->text(), Qt::MatchStartsWith | Qt::MatchRecursive);
-
-		objectslist_tbw->blockSignals(true);
-		for(int row=0; row < objectslist_tbw->rowCount(); row++)
-			objectslist_tbw->setRowHidden(row, true);
-
-		while(!items.isEmpty())
-		{
-			objectslist_tbw->setRowHidden(items.front()->row(), false);
-			items.pop_front();
-		}
-
-		objectslist_tbw->blockSignals(false);
-	}
+	DatabaseImportForm::filterObjects(objectstree_tw, filter_edt->text(), (by_id_chk->isChecked() ? 1 : 0), simplified_view);
 }
 
 void ModelObjectsWidget::updateObjectsView()
 {
 	selected_objs.clear();
 	updateDatabaseTree();
-	updateObjectsList();
 
 	if(!filter_edt->text().isEmpty())
 		filterObjects();
 }
 
-void ModelObjectsWidget::updateObjectsList()
-{
-	std::vector<BaseObject *> objects;
-
-	if(db_model)
-	{
-		std::vector<ObjectType> visible_types;
-
-		for(auto &tp : visible_objs_map)
-		{
-			if(tp.second)
-				visible_types.push_back(tp.first);
-		}
-
-		objects = db_model->findObjects("*", visible_types, false, false, false);
-	}
-
-	GuiUtilsNs::updateObjectTable(objectslist_tbw, objects);
-	objectslist_tbw->clearSelection();
-}
-
 void ModelObjectsWidget::updateSchemaTree(QTreeWidgetItem *root)
 {
 	if(db_model && visible_objs_map[ObjectType::Schema])
@@ -495,9 +428,9 @@ void ModelObjectsWidget::updateSchemaTree(QTreeWidgetItem *root)
 		BaseObject *schema=nullptr;
 		std::vector<BaseObject *> obj_list;
 		QFont font;
-		QTreeWidgetItem *item=nullptr, *item1=nullptr, *item2=nullptr, *item3=nullptr;
+		QTreeWidgetItem *item = nullptr, *item1=nullptr, *item2=nullptr;
 		std::vector<ObjectType> types = BaseObject::getChildObjectTypes(ObjectType::Schema);
-		int count = 0, count2 = 0, i = 0;
+		int count = 0;
 		QPixmap group_icon=QPixmap(GuiUtilsNs::getIconPath(QString(BaseObject::getSchemaName(ObjectType::Schema))));
 
 		//Removing the ObjectType::Table and ObjectType::View types since they are handled separetedly
@@ -506,64 +439,55 @@ void ModelObjectsWidget::updateSchemaTree(QTreeWidgetItem *root)
 		types.erase(std::find(types.begin(), types.end(), ObjectType::View));
 
 		//Get the current schema count on database
-		count=(db_model->getObjectCount(ObjectType::Schema));
-		item=new QTreeWidgetItem(root);
+		count = (db_model->getObjectCount(ObjectType::Schema));
+		item = new QTreeWidgetItem(root);
 		item->setIcon(0,group_icon);
 		item->setData(1, Qt::UserRole, QVariant(enum_t(ObjectType::Schema)));
 
 		//Create the schema group item
 		item->setText(0, QString("%1 (%2)").arg(BaseObject::getTypeName(ObjectType::Schema)).arg(count));
-		font=item->font(0);
+		item->setData(2, Qt::UserRole, QString("%1_grp").arg(BaseObject::getSchemaName(ObjectType::Schema)));
+
+		font = item->font(0);
 		font.setItalic(true);
 		item->setFont(0, font);
 
 		try
 		{
-			for(i=0; i < count; i++)
+			for(auto &sch_obj : *db_model->getObjectList(ObjectType::Schema))
 			{
-				//The first item is the public schema
-				if(i==-1)
-				{
-					//The new sub item to be configured will be the public schema item
-					item2=item1;
-					schema=nullptr;
-				}
-				else
-				{
-					schema=db_model->getObject(i, ObjectType::Schema);
-					item2=createItemForObject(schema, item);
-				}
+				schema = dynamic_cast<Schema *>(sch_obj);
+				item1 = createItemForObject(schema, item);
 
 				//Updates the table subtree for the current schema
-				updateTableTree(item2, schema, ObjectType::Table);
+				updateTableTree(item1, schema, ObjectType::Table);
 
 				//Updates the foreign table subtree for the current schema
-				updateTableTree(item2, schema, ObjectType::ForeignTable);
+				updateTableTree(item1, schema, ObjectType::ForeignTable);
 
 				//Updates the view subtree for the current schema
-				updateViewTree(item2, schema);
+				updateViewTree(item1, schema);
 
 				//Creates the object group at schema level (function, domain, sequences, etc)
-				for(auto type : types)
+				for(auto &type : types)
 				{
 					if(visible_objs_map[type])
 					{
-						item3=new QTreeWidgetItem(item2);
-						item3->setIcon(0,QPixmap(GuiUtilsNs::getIconPath(BaseObject::getSchemaName(type))));
+						item2 = new QTreeWidgetItem(item1);
+						item2->setIcon(0,QPixmap(GuiUtilsNs::getIconPath(BaseObject::getSchemaName(type))));
 
 						//Get the objects that belongs to the current schema
-						obj_list=db_model->getObjects(type, schema);
+						obj_list = db_model->getObjects(type, schema);
+						item2->setText(0, QString("%1 (%2)").arg(BaseObject::getTypeName(type)).arg(obj_list.size()));
+						item2->setData(1, Qt::UserRole, QVariant(enum_t(type)));
+						item2->setData(2, Qt::UserRole, QString("%1_%2_grp").arg(schema->getObjectId()).arg(BaseObject::getSchemaName(type)));
 
-						count2=obj_list.size();
-						item3->setText(0, QString("%1 (%2)").arg(BaseObject::getTypeName(type)).arg(count2));
-						item3->setData(1, Qt::UserRole, QVariant(enum_t(type)));
-
-						font=item3->font(0);
+						font = item2->font(0);
 						font.setItalic(true);
-						item3->setFont(0, font);
+						item2->setFont(0, font);
 
-						for(auto obj : obj_list)
-							createItemForObject(obj, item3);
+						for(auto &obj : obj_list)
+							createItemForObject(obj, item2);
 					}
 				}
 			}
@@ -580,11 +504,11 @@ void ModelObjectsWidget::updateTableTree(QTreeWidgetItem *root, BaseObject *sche
 	if(db_model && PhysicalTable::isPhysicalTable(table_type) && visible_objs_map[table_type])
 	{
 		std::vector<BaseObject *> obj_list;
-		PhysicalTable *table=nullptr;
-		QTreeWidgetItem *item=nullptr, *item1=nullptr, *item2=nullptr;
+		PhysicalTable *table = nullptr;
+		QTreeWidgetItem *item = nullptr, *item1 = nullptr, *item2 = nullptr;
 		QFont font;
 		std::vector<ObjectType> types = BaseObject::getChildObjectTypes(table_type);
-		QPixmap group_icon=QPixmap(GuiUtilsNs::getIconPath(BaseObject::getSchemaName(table_type)));
+		QPixmap group_icon = QPixmap(GuiUtilsNs::getIconPath(BaseObject::getSchemaName(table_type)));
 
 		try
 		{
@@ -594,31 +518,32 @@ void ModelObjectsWidget::updateTableTree(QTreeWidgetItem *root, BaseObject *sche
 			//Create a table group item
 			item=new QTreeWidgetItem(root);
 			item->setIcon(0,group_icon);
-			item->setText(0,BaseObject::getTypeName(table_type) +
-						  QString(" (%1)").arg(obj_list.size()));
+			item->setText(0, BaseObject::getTypeName(table_type) + QString(" (%1)").arg(obj_list.size()));
 			item->setData(1, Qt::UserRole, QVariant(enum_t(table_type)));
+			item->setData(2, Qt::UserRole, QString("%1_%2_grp").arg(schema->getObjectId()).arg(BaseObject::getSchemaName(table_type)));
 
 			font=item->font(0);
 			font.setItalic(true);
 			item->setFont(0, font);
 
-			for(auto obj : obj_list)
+			for(auto &obj : obj_list)
 			{
-				table=dynamic_cast<PhysicalTable *>(obj);
-				item1=createItemForObject(table, item);
+				table = dynamic_cast<PhysicalTable *>(obj);
+				item1 = createItemForObject(table, item);
 
 				//Creating the group for the child objects (column, rules, triggers, indexes and constraints)
-				for(auto type : types)
+				for(auto &type : types)
 				{
 					if(visible_objs_map[type])
 					{
-						item2=new QTreeWidgetItem(item1);
+						item2 = new QTreeWidgetItem(item1);
 						item2->setIcon(0,QPixmap(GuiUtilsNs::getIconPath(BaseObject::getSchemaName(type))));
-						font=item2->font(0);
+						font = item2->font(0);
 						font.setItalic(true);
 						item2->setFont(0, font);
 
 						item2->setText(0, QString("%1 (%2)").arg(BaseObject::getTypeName(type)).arg(table->getObjectCount(type)));
+						item2->setData(2, Qt::UserRole, QString("%1_%2_grp").arg(table->getObjectId()).arg(BaseObject::getSchemaName(type)));
 
 						for(auto tab_obj : *table->getObjectList(type))
 							createItemForObject(tab_obj, item2);
@@ -637,56 +562,50 @@ void ModelObjectsWidget::updateViewTree(QTreeWidgetItem *root, BaseObject *schem
 {
 	if(db_model && visible_objs_map[ObjectType::View])
 	{
-		BaseObject *object=nullptr;
 		std::vector<BaseObject *> obj_list;
-		View *view=nullptr;
-		QTreeWidgetItem *item=nullptr, *item1=nullptr, *item2=nullptr;
+		View *view = nullptr;
+		QTreeWidgetItem *item = nullptr, *item1 = nullptr, *item2 = nullptr;
 		QFont font;
 		std::vector<ObjectType> types = BaseObject::getChildObjectTypes(ObjectType::View);
-		int count = 0, count1 = 0, i = 0, i2 = 0;
-		QPixmap group_icon=QPixmap(GuiUtilsNs::getIconPath(QString(BaseObject::getSchemaName(ObjectType::View))));
+		QPixmap group_icon = QPixmap(GuiUtilsNs::getIconPath(QString(BaseObject::getSchemaName(ObjectType::View))));
 
 		try
 		{
 			//Get all views that belongs to the specified schema
-			obj_list=db_model->getObjects(ObjectType::View, schema);
+			obj_list = db_model->getObjects(ObjectType::View, schema);
 
 			//Create a table group item
 			item=new QTreeWidgetItem(root);
-			item->setIcon(0,group_icon);
-			item->setText(0,BaseObject::getTypeName(ObjectType::View) + QString(" (%1)").arg(obj_list.size()));
+			item->setIcon(0, group_icon);
+			item->setText(0, BaseObject::getTypeName(ObjectType::View) + QString(" (%1)").arg(obj_list.size()));
 			item->setData(1, Qt::UserRole, QVariant(enum_t(ObjectType::View)));
+			item->setData(2, Qt::UserRole, QString("%1_%2_grp").arg(schema->getObjectId()).arg(BaseObject::getSchemaName(ObjectType::View)));
 
-			font=item->font(0);
+			font = item->font(0);
 			font.setItalic(true);
 			item->setFont(0, font);
 
-			count=obj_list.size();
-
-			for(i=0; i < count; i++)
+			for(auto &obj : obj_list)
 			{
-				view=dynamic_cast<View *>(obj_list[i]);
-				item1=createItemForObject(view, item);
+				view = dynamic_cast<View *>(obj);
+				item1 = createItemForObject(view, item);
 
 				//Creating the group for the child objects (rules, triggers)
 				for(auto &type : types)
 				{
 					if(visible_objs_map[type])
 					{
-						item2=new QTreeWidgetItem(item1);
+						item2 = new QTreeWidgetItem(item1);
 						item2->setIcon(0,QPixmap(GuiUtilsNs::getIconPath(BaseObject::getSchemaName(type))));
-						font=item2->font(0);
+						font = item2->font(0);
 						font.setItalic(true);
 						item2->setFont(0, font);
 
-						count1 = view->getObjectCount(type);
-						item2->setText(0,BaseObject::getTypeName(type) + QString(" (%1)").arg(count1));
+						item2->setText(0, BaseObject::getTypeName(type) + QString(" (%1)").arg(view->getObjectCount(type)));
+						item2->setData(2, Qt::UserRole, QString("%1_%2_grp").arg(view->getObjectId()).arg(BaseObject::getSchemaName(type)));
 
-						for(i2=0; i2 < count1; i2++)
-						{
-							object=view->getObject(i2, type);
+						for(auto &object : view->getObjects())
 							createItemForObject(object, item2);
-						}
 					}
 				}
 			}
@@ -706,7 +625,7 @@ void ModelObjectsWidget::updatePermissionTree(QTreeWidgetItem *root, BaseObject
 				Permission::acceptsPermission(object->getObjectType()))
 		{
 			std::vector<Permission *> perms;
-			QTreeWidgetItem *item=new QTreeWidgetItem(root);
+			QTreeWidgetItem *item = new QTreeWidgetItem(root);
 			QFont font=item->font(0);
 
 			db_model->getPermissions(object, perms);
@@ -715,10 +634,10 @@ void ModelObjectsWidget::updatePermissionTree(QTreeWidgetItem *root, BaseObject
 			font.setItalic(true);
 			item->setFont(0, font);
 			item->setText(0, QString("%1 (%2)")
-							.arg(BaseObject::getTypeName(ObjectType::Permission))
-						  .arg(perms.size()));
+											.arg(BaseObject::getTypeName(ObjectType::Permission))
+											.arg(perms.size()));
 
-			item->setData(0, Qt::UserRole, generateItemValue(object));
+			item->setData(0, Qt::UserRole, generateItemData(object));
 			item->setData(1, Qt::UserRole, static_cast<unsigned>(ObjectType::Permission));
 		}
 	}
@@ -735,12 +654,14 @@ void ModelObjectsWidget::updateDatabaseTree()
 	else
 	{
 		QString str_aux;
-		BaseObject *object=nullptr;
 		QTreeWidgetItem *root=nullptr,*item1=nullptr, *item2=nullptr;
 		QFont font;
-		std::vector<BaseObject *> ref_list, tree_state, obj_list;
+		std::vector<BaseObject *> obj_list;
 		std::vector<ObjectType> types = BaseObject::getChildObjectTypes(ObjectType::Database);
-		unsigned count = 0, i = 0, i1 = 0;
+		int tree_v_pos = 0;
+		QStringList tree_state;
+
+		objectstree_tw->setUpdatesEnabled(false);
 
 		types.push_back(ObjectType::Tag);
 		types.push_back(ObjectType::GenericSql);
@@ -748,18 +669,17 @@ void ModelObjectsWidget::updateDatabaseTree()
 		types.push_back(ObjectType::Relationship);
 		types.erase(std::find(types.begin(), types.end(), ObjectType::Schema));
 
+		if(save_tree_state)
+			saveTreeState(tree_state, tree_v_pos);
+
 		try
 		{
-			if(save_tree_state)
-				saveTreeState(tree_state);
-
-			//objectstree_tw->setUpdatesEnabled(false);
 			objectstree_tw->clear();
 
 			if(visible_objs_map[ObjectType::Database])
 			{
-				root=createItemForObject(db_model);
-				objectstree_tw->insertTopLevelItem(0,root);
+				root = createItemForObject(db_model);
+				objectstree_tw->insertTopLevelItem(0, root);
 
 				updateSchemaTree(root);
 
@@ -767,57 +687,55 @@ void ModelObjectsWidget::updateDatabaseTree()
 				{
 					if(visible_objs_map[type])
 					{
-						item1=new QTreeWidgetItem(root);
-						str_aux=QString(BaseObject::getSchemaName(type));
+						item1 = new QTreeWidgetItem(root);
+						str_aux = QString(BaseObject::getSchemaName(type));
 
-						item1->setIcon(0,QPixmap(GuiUtilsNs::getIconPath(str_aux)));
+						item1->setIcon(0, QPixmap(GuiUtilsNs::getIconPath(str_aux)));
 						item1->setData(1, Qt::UserRole, QVariant(enum_t(type)));
 
 						obj_list=(*db_model->getObjectList(type));
 
 						//Special case for relationship, merging the base relationship list to the relationship list
-						if(type==ObjectType::Relationship)
+						if(type == ObjectType::Relationship)
 						{
 							std::vector<BaseObject *> obj_list_aux;
 							obj_list_aux=(*db_model->getObjectList(ObjectType::BaseRelationship));
 							obj_list.insert(obj_list.end(), obj_list_aux.begin(), obj_list_aux.end());
 						}
 
-						count=obj_list.size();
-						item1->setText(0,BaseObject::getTypeName(type) + QString(" (%1)").arg(count));
-						font=item1->font(0);
+						item1->setText(0, BaseObject::getTypeName(type) + QString(" (%1)").arg(obj_list.size()));
+						item1->setData(2, Qt::UserRole, QString("%1_%2_grp").arg(db_model->getObjectId()).arg(BaseObject::getSchemaName(type)));
+						font = item1->font(0);
 						font.setItalic(true);
 						item1->setFont(0, font);
 
-						for(i1=0; i1 < count; i1++)
+						for(auto &object : obj_list)
 						{
-							object=obj_list.at(i1);
-							item2=createItemForObject(object, item1);
+							item2 = createItemForObject(object, item1);
 
-							if(types[i]==ObjectType::Tag)
+							if(type == ObjectType::Tag)
 							{
-								db_model->getObjectReferences(object, ref_list);
-
-								for(auto &ref : ref_list)
+								for(auto &ref : object->getReferences())
 									createItemForObject(ref, item2, false);
 							}
 						}
 					}
 				}
 
-				//objectstree_tw->setUpdatesEnabled(true);
 				objectstree_tw->expandItem(root);
-
-				if(save_tree_state)
-					restoreTreeState(tree_state);
 			}
 		}
 		catch(Exception &e)
 		{
-			throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+			objectstree_tw->setUpdatesEnabled(true);
+			Messagebox::error(e, __PRETTY_FUNCTION__, __FILE__, __LINE__);
 		}
 
 		objectstree_tw->sortByColumn(0, Qt::AscendingOrder);
+		objectstree_tw->setUpdatesEnabled(true);
+
+		if(save_tree_state)
+			restoreTreeState(tree_state, tree_v_pos);
 	}
 }
 
@@ -842,15 +760,9 @@ void ModelObjectsWidget::close()
 		selected_objs.clear();
 	else
 	{
-		QVariant data;
 		BaseObject *selected_obj = nullptr;
 
-		if(tree_view_tb->isChecked() && objectstree_tw->currentItem())
-			data = objectstree_tw->currentItem()->data(0,Qt::UserRole);
-		else if(objectslist_tbw->currentItem())
-			data = objectslist_tbw->currentItem()->data(Qt::UserRole);
-
-		selected_obj = reinterpret_cast<BaseObject *>(data.value<void *>());
+		selected_obj = getTreeItemData(objectstree_tw->currentItem());
 
 		if(selected_obj && std::find(selected_objs.begin(), selected_objs.end(), selected_obj) == selected_objs.end())
 			selected_objs.push_back(selected_obj);
@@ -875,12 +787,9 @@ void ModelObjectsWidget::setModel(DatabaseModel *db_model)
 
 	this->db_model=db_model;
 	content_wgt->setEnabled(enable);
-	updateObjectsView();
-	visaoobjetos_stw->setEnabled(true);
-	expand_all_tb->setEnabled(enable && tree_view_tb->isChecked());
-	collapse_all_tb->setEnabled(enable && tree_view_tb->isChecked());
-	tree_view_tb->setEnabled(enable);
-	list_view_tb->setEnabled(enable);
+	updateObjectsView();	
+	expand_all_tb->setEnabled(enable);
+	collapse_all_tb->setEnabled(enable);
 	options_tb->setEnabled(enable);
 	filter_lbl->setEnabled(enable);
 	filter_edt->setEnabled(enable);
@@ -978,86 +887,83 @@ void ModelObjectsWidget::saveTreeState(bool value)
 void ModelObjectsWidget::clearSelectedObject()
 {
 	objectstree_tw->blockSignals(true);
-	objectslist_tbw->blockSignals(true);
 	objectstree_tw->clearSelection();
-	objectslist_tbw->clearSelection();
 	objectstree_tw->blockSignals(false);
-	objectslist_tbw->blockSignals(false);
 	selected_objs.clear();
 	model_wgt->configurePopupMenu(nullptr);
 	model_wgt->emitSceneInteracted();
 }
 
-void ModelObjectsWidget::saveTreeState(std::vector<BaseObject *> &tree_items)
+void ModelObjectsWidget::saveTreeState(QStringList &exp_items_ids, int &v_scroll_pos)
 {
 	QTreeWidgetItemIterator itr(objectstree_tw);
-	BaseObject *obj=nullptr;
 	QTreeWidgetItem *item=nullptr;
 
 	while(*itr)
 	{
-		item=*itr;
-		obj=reinterpret_cast<BaseObject *>(item->data(0,Qt::UserRole).value<void *>());
+		item = *itr;
 
-		if(obj && item->parent() && item->parent()->isExpanded())
-			tree_items.push_back(obj);
+		if(item->isExpanded())
+			exp_items_ids.push_back(item->data(2, Qt::UserRole).toString());
 
 		++itr;
 	}
+
+	v_scroll_pos = objectstree_tw->verticalScrollBar()->value();
 }
 
-void ModelObjectsWidget::restoreTreeState(std::vector<BaseObject *> &tree_items)
+void ModelObjectsWidget::restoreTreeState(const QStringList &exp_items_ids, int v_scroll_pos)
 {
-	QTreeWidgetItem *item=nullptr, *parent_item=nullptr;
+	QTreeWidgetItem *item = nullptr;
 
-	objectslist_tbw->setUpdatesEnabled(false);
-
-	while(!tree_items.empty())
+	for(auto &item_id : exp_items_ids)
 	{
-		item=getTreeItem(tree_items.back());
+		item = getTreeItem(item_id);
 
-		if(item)
-		{
-			parent_item=item->parent();
+		if(!item)
+			continue;
 
-			if(parent_item)
-				objectstree_tw->expandItem(parent_item);
-
-			if(parent_item && parent_item->parent())
-				objectstree_tw->expandItem(parent_item->parent());
-		}
-
-		tree_items.pop_back();
+		objectstree_tw->expandItem(item);
 	}
 
-	objectslist_tbw->setUpdatesEnabled(true);
+	objectstree_tw->verticalScrollBar()->setValue(v_scroll_pos);
 }
 
 QTreeWidgetItem *ModelObjectsWidget::getTreeItem(BaseObject *object)
 {
-	if(object)
+	if(!object)
+		return nullptr;
+
+	QTreeWidgetItemIterator itr(objectstree_tw);
+
+	while(*itr)
 	{
-		QTreeWidgetItemIterator itr(objectstree_tw);
-		BaseObject *aux_obj=nullptr;
-		QTreeWidgetItem *item=nullptr;
+		if(getTreeItemData(*itr) == object)
+			return *itr;
 
-		while(*itr)
+		++itr;
+	}
+
+	return nullptr;
+}
+
+QTreeWidgetItem *ModelObjectsWidget::getTreeItem(const QString &item_id)
+{
+	QTreeWidgetItemIterator itr(objectstree_tw);
+	QTreeWidgetItem *item = nullptr;
+
+	while(*itr)
+	{
+		if((*itr)->data(2, Qt::UserRole).toString() == item_id)
 		{
-			aux_obj=reinterpret_cast<BaseObject *>((*itr)->data(0,Qt::UserRole).value<void *>());
-
-			if(aux_obj==object)
-			{
-				item=*itr;
-				break;
-			}
-
-			++itr;
+			item = *itr;
+			break;
 		}
 
-		return item;
+		++itr;
 	}
-	else
-		return nullptr;
+
+	return item;
 }
 
 void ModelObjectsWidget::selectCreatedObject(BaseObject *obj)
