@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,10 +30,10 @@ they must inherit from this class.
 #include "globalattributes.h"
 
 class PgModelerUnitTest {
-    public:
-	    PgModelerUnitTest(const QString &search_path){
-			GlobalAttributes::setSearchPath(search_path);
-	};
+	public:
+		PgModelerUnitTest(const QString &search_path){
+			GlobalAttributes::init(search_path, false);
+	}
 };
 
 #endif
